Package: modeldata
Title: Data Sets Useful for Modeling Examples
Version: 1.6.0
Authors@R: c(
    person("Max", "Kuhn", , "max@posit.co", role = c("aut", "cre")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Data sets used for demonstrating or testing model-related
    packages are contained in this package.
License: MIT + file LICENSE
URL: https://modeldata.tidymodels.org,
        https://github.com/tidymodels/modeldata
BugReports: https://github.com/tidymodels/modeldata/issues
Depends: R (>= 4.1)
Imports: cli, dplyr, MASS, purrr, rlang (>= 1.1.0), tibble
Suggests: covr, ggplot2, testthat (>= 3.0.0)
Config/Needs/website: tidyverse/tidytemplate, tidymodels/tidymodels
Config/testthat/edition: 3
Config/usethis/last-upkeep: 2025-04-27
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-08-20 16:40:58 UTC; max
Author: Max Kuhn [aut, cre],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Max Kuhn <max@posit.co>
Repository: CRAN
Date/Publication: 2026-08-21 11:10:02 UTC
Built: R 4.5.2; ; 2026-08-21 13:05:04 UTC; unix

Package: modeldata
Title: Data Sets Useful for Modeling Examples
Version: 1.5.1
Authors@R: c(
    person("Max", "Kuhn", , "max@posit.co", role = c("aut", "cre")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Data sets used for demonstrating or testing model-related
    packages are contained in this package.
License: MIT + file LICENSE
URL: https://modeldata.tidymodels.org,
        https://github.com/tidymodels/modeldata
BugReports: https://github.com/tidymodels/modeldata/issues
Depends: R (>= 4.1)
Imports: cli, dplyr, MASS, purrr, rlang (>= 1.1.0), tibble
Suggests: covr, ggplot2, testthat (>= 3.0.0)
Config/Needs/website: tidyverse/tidytemplate, tidymodels/tidymodels
Config/testthat/edition: 3
Config/usethis/last-upkeep: 2025-04-27
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-21 19:27:19 UTC; max
Author: Max Kuhn [aut, cre],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Max Kuhn <max@posit.co>
Repository: CRAN
Date/Publication: 2025-08-22 06:20:02 UTC
Built: R 4.6.0; ; 2026-04-29 01:37:08 UTC; unix

# Generated by roxygen2: do not edit by hand

export(sim_classification)
export(sim_logistic)
export(sim_multinomial)
export(sim_noise)
export(sim_regression)
import(rlang)
importFrom(stats,rnorm)
importFrom(stats,runif)

<!-- README.md is generated from README.Rmd. Please edit that file -->

# modeldata

<!-- badges: start -->

[![CRAN
status](https://www.r-pkg.org/badges/version/modeldata)](https://CRAN.R-project.org/package=modeldata)
[![R-CMD-check](https://github.com/tidymodels/modeldata/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/tidymodels/modeldata/actions/workflows/R-CMD-check.yaml)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html)
<!-- badges: end -->

`modeldata` contains data sets used in documentation and testing for
tidymodels packages. The package also contains a suite of simulation
functions for classification and regression data.

## Installation

You can install the released version of modeldata from
[CRAN](https://CRAN.R-project.org) with:

``` r
install.packages("modeldata")
```

And the development version from [GitHub](https://github.com/) with:

``` r
# install.packages("pak")
pak::pak("tidymodels/modeldata")
```

## Contributing

This project is released with a [Contributor Code of
Conduct](https://contributor-covenant.org/version/2/1/CODE_OF_CONDUCT.html).
By contributing to this project, you agree to abide by its terms.

- For questions and discussions about tidymodels packages, modeling, and
  machine learning, please [post on RStudio
  Community](https://forum.posit.co/new-topic?category_id=15&tags=tidymodels,question).

- If you think you have encountered a bug, please [submit an
  issue](https://github.com/tidymodels/modeldata/issues).

- Either way, learn how to create and share a
  [reprex](https://reprex.tidyverse.org/articles/articles/learn-reprex.html)
  (a minimal, reproducible example), to clearly communicate about your
  code.

- Check out further details on [contributing guidelines for tidymodels
  packages](https://www.tidymodels.org/contribute/) and [how to get
  help](https://www.tidymodels.org/help/).

#' Example bivariate classification data
#'
#' @details These data are a simplified version of the segmentation data contained
#' in `caret`. There are three columns: `A` and `B` are predictors and the column
#' `Class` is a factor with levels "One" and "Two". There are three data sets:
#' one for training (n = 1009), validation (n = 300), and testing (n = 710).
#'
#' @name bivariate
#' @aliases bivariate_train  bivariate_test bivariate_val
#' @docType data
#' @return \item{bivariate_train, bivariate_test, bivariate_val}{tibbles}
#'
#' @keywords datasets
#' @examples
#' data(bivariate)
#' str(bivariate_train)
#' str(bivariate_val)
#' str(bivariate_test)
NULL

#' Solubility predictions from MARS model
#'
#' @details For the solubility data in Kuhn and Johnson (2013),
#'  these data are the test set results for the MARS model. The
#'  observed solubility (in column `solubility`) and the model
#'  results (`prediction`) are contained in the data.
#'
#' @name solubility_test
#' @aliases solubility_test
#' @docType data
#' @return \item{solubility_test}{a data frame}
#'
#' @source Kuhn, M., Johnson, K. (2013) *Applied Predictive
#'  Modeling*, Springer
#'
#' @keywords datasets
#' @examples
#' data(solubility_test)
#' str(solubility_test)
NULL

#' Tate Gallery modern artwork metadata
#'
#' Metadata such as artist, title, and year created for recent artworks owned
#'  by the Tate Gallery. Only artworks created during or after 1990 are
#'  included, and the metadata source was last updated in 2014. The Tate Gallery
#'  provides these data but requests users to be respectful of their
#'  [guidelines for use](https://github.com/tategallery/collection#usage-guidelines-for-open-data).
#'
#' @name tate_text
#' @aliases tate_text
#' @docType data
#' @return \item{tate_text}{a tibble}
#'
#' @source \itemize{
#' \item \url{https://github.com/tategallery/collection}
#' \item \url{https://www.tate.org.uk/}
#' }
#'
#' @keywords datasets
#' @examples
#' data(tate_text)
#' str(tate_text)
NULL

#' OkCupid text data
#'
#' These are a sample of columns and users of OkCupid dating
#'  website. The data are from Kim and Escobedo-Land (2015).
#'  Permission to use this data set was explicitly granted by
#'  OkCupid. The data set contains 10 text fields filled out by
#'  users. There is an field called `Class` that is a factor with
#'  levels "stem" and "other" where a value of "stem" means that
#'  the user had a job in Science, Technology, Engineering, or
#'  Math.

#'
#' @name okc_text
#' @aliases okc_text
#' @docType data
#' @return \item{okc_text}{a tibble}
#'
#' @source Kim, A. Y., and A. Escobedo-Land. 2015. "OkCupid Data for
#'   Introductory Statistics and Data Science Courses." *Journal of
#'   Statistics Education: An International Journal on the Teaching and
#'   Learning of Statistics*.
#'
#' @keywords datasets
#' @examples
#' data(okc_text)
#' str(okc_text)
NULL

#' Daily Hotel Rate Data
#'
#' @description
#' A data set to predict the average daily rate for a hotel in Lisbon Portugal.
#'
#' @name hotel_rates
#' @aliases hotel_rates
#' @docType data
#'
#' @details
#'
#' Data are originally described in Antonio, de Almeida, and Nunes (2019).
#' This version of the data is filtered for one hotel (the "Resort Hotel") and
#' is intended as regression data set for predicting the average daily rate for
#' a room. The data are post-2016; the 2016 data were used to have a predictor
#' for the historical daily rates. See the `hotel_rates.R` file in the
#' `data-raw` directory of the package to understand other filters used when
#' creating this version of the data.
#'
#' The `agent` and `company` fields were changed from random characters to use
#' a set of random names.
#'
#' The outcome column is `avg_price_per_room`.
#'
#' ## License
#'
#' No license was given for the data; See the reference below for source.
#'
#' @source
#' \url{https://github.com/rfordatascience/tidytuesday/tree/master/data/2020/2020-02-11}
#'
#' @references
#' Antonio, N., de Almeida, A., and Nunes, L. (2019). Hotel booking demand
#' datasets. _Data in Brief_, 22, 41-49.
#'
#' @keywords datasets
#' @examples
#' \dontrun{
#' str(hotel_rates)
#' }
NULL

#' Cat Adoption
#'
#' @description
#' A subset of the cats at the animal shelter in Long Beach, California, USA.
#'
#' @return tibble
#' @aliases cat_adoption
#' @name cat_adoption
#' @docType data
#' @details
#'
#' A data frame with 2257 rows and 19 columns:
#' \describe{
#'   \item{time}{The time the cat spent at the shelter.}
#'   \item{event}{The event of interest is the cat being homed or returned to
#'   its original location (i.e., owner or community). The non-event is the cat
#'   being transferred to another shelter or dying. Zero indicates a non-event
#'   (censored), and one corresponds to the event occurring.}
#'   \item{sex}{The sex of the cat.}
#'   \item{neutered}{Whether the cat is neutered.}
#'   \item{intake_condition}{The intake condition of the cat.}
#'   \item{intake_type}{The type of intake.}
#'   \item{latitude}{Latitude of the intersection/cross street of intake or capture.}
#'   \item{longitude}{Longitude of the intersection/cross street of intake or capture.}
#'  \item{black,brown,brown_tabby,calico,cream,gray,gray_tabby,orange,orange_tabby,tan,tortie,white}{Indicators for the color/pattern of the cat's fur.}
#' }
#' @source
#'
#' <https://data.longbeach.gov/explore/dataset/animal-shelter-intakes-and-outcomes/information/>
#' on 2024-06-17
#'
#' @examples
#' str(cat_adoption)
#' @keywords datasets
NULL

#' Simulate datasets
#'
#' These functions can be used to generate simulated data for supervised
#' (classification and regression) and unsupervised modeling applications.
#'
#' @param num_samples Number of data points to simulate.
#' @param method A character string for the simulation method. For
#' classification, the single current option is "caret". For regression,
#' values can be `"sapp_2014_1"`, `"sapp_2014_2"`, `"van_der_laan_2007_1"`,
#' `"van_der_laan_2007_2"`, `"hooker_2004"`, or `"worley_1987"`. See Details
#' below.
#' @param intercept The intercept for the linear predictor.
#' @param num_linear Number of diminishing linear effects.
#' @param std_dev Gaussian distribution standard deviation for residuals.
#' Default values are shown below in Details.
#' @param num_vars Number of noise predictors to create.
#' @param cov_type The multivariate normal correlation structure of the
#' predictors. Possible values are "exchangeable" and "toeplitz".
#' @param cov_param A single numeric value for the exchangeable correlation
#' value or the base of the Toeplitz structure. See Details below.
#' @param factors A single logical for whether the binary indicators should be
#' encoded as factors or not.
#' @param outcome A single character string for what type of independent outcome
#' should be simulated (if any). The default value of "none" produces no extra
#' columns. Using "classification" will generate a `class` column with
#' `num_classes` values, equally distributed. A value of "regression" results
#' in an `outcome` column that contains independent standard normal values.
#' @param num_classes When `outcome = "classification"`, the number of classes
#' to simulate.
#' @param keep_truth A logical: should the true outcome value be retained for
#' the data? If so, the column name is `.truth`.
#' @param eqn,eqn_1,eqn_2,eqn_3 An R expression or  (one sided) formula that
#' only involves variables `A` and `B` that is used to compute the linear
#' predictor. External objects should not be used as symbols; see the examples
#' below on how to use external objects in the equations.
#' @param correlation A single numeric value for the correlation between variables
#'  `A` and `B`.
#'
#' @details
#'
#' ## Specific Regression and Classification methods
#'
#' These functions provide several supervised simulation methods (and one
#' unsupervised). Learn more by `method`:
#'
#' ### `method = "caret"`
#'
#' This is a simulated classification problem with two classes, originally
#'  implemented in [caret::twoClassSim()] with all numeric predictors. The
#'  predictors are simulated in different sets. First, two multivariate normal
#'  predictors (denoted here as `two_factor_1` and `two_factor_2`) are created
#'  with a correlation of about 0.65. They change the log-odds using main
#'  effects and an interaction:
#'
#' \preformatted{  intercept - 4 * two_factor_1 + 4 * two_factor_2 + 2 * two_factor_1 * two_factor_2 }
#'
#' The intercept is a parameter for the simulation and can be used to control
#' the amount of class imbalance.
#'
#' The effects in the second set are linear with coefficients that alternate signs
#' and have a sequence of values between 2.5 and 0.25. For example, if there
#' were four predictors in this set, their contribution to the log-odds would
#' be
#'
#' \preformatted{  -2.5 * linear_1 + 1.75 * linear_2 -1.00 * linear_3 + 0.25 * linear_4}
#'
#' (Note that these column names may change based on the value of `num_linear`).
#'
#' The third set is a nonlinear function of a single predictor ranging between
#' `[0, 1]` called `non_linear_1` here:
#'
#' \preformatted{  (non_linear_1^3) + 2 * exp(-6 * (non_linear_1 - 0.3)^2) }
#'
#' The fourth set of informative predictors is copied from one of Friedman's
#' systems and use two more predictors (`non_linear_2` and `non_linear_3`):
#'
#' \preformatted{  2 * sin(non_linear_2 * non_linear_3) }
#'
#' All of these effects are added up to model the log-odds.
#'
#' ### `method = "sapp_2014_1"`
#'
#' This regression simulation is from Sapp et al. (2014). There are 20
#' independent Gaussian random predictors with mean zero and a variance of 9.
#' The prediction equation is:
#'
#' \preformatted{
#'   predictor_01 + sin(predictor_02) + log(abs(predictor_03)) +
#'    predictor_04^2 + predictor_05 * predictor_06 +
#'    ifelse(predictor_07 * predictor_08 * predictor_09 < 0, 1, 0) +
#'    ifelse(predictor_10 > 0, 1, 0) + predictor_11 * ifelse(predictor_11 > 0, 1, 0) +
#'    sqrt(abs(predictor_12)) + cos(predictor_13) + 2 * predictor_14 + abs(predictor_15) +
#'    ifelse(predictor_16 < -1, 1, 0) + predictor_17 * ifelse(predictor_17 < -1, 1, 0) -
#'    2 * predictor_18 - predictor_19 * predictor_20
#' }
#'
#' The error is Gaussian with mean zero and variance 9.
#'
#' ### `method = "sapp_2014_2"`
#'
#' This regression simulation is also from Sapp et al. (2014). There are 200
#' independent Gaussian predictors with mean zero and variance 16. The
#' prediction equation has an intercept of one and identical linear effects of
#' `log(abs(predictor))`.
#'
#' The error is Gaussian with mean zero and variance 25.
#'
#' ### `method = "van_der_laan_2007_1"`
#'
#' This is a regression simulation from van der Laan et al. (2007) with ten
#' random Bernoulli variables that have a 40% probability of being a value of
#' one. The true regression equation is:
#'
#' \preformatted{
#'   2 * predictor_01 * predictor_10 + 4 * predictor_02 * predictor_07 +
#'     3 * predictor_04 * predictor_05 - 5 * predictor_06 * predictor_10 +
#'     3 * predictor_08 * predictor_09 + predictor_01 * predictor_02 * predictor_04 -
#'     2 * predictor_07 * (1 - predictor_06) * predictor_02 * predictor_09 -
#'     4 * (1 - predictor_10) * predictor_01 * (1 - predictor_04)
#' }
#'
#' The error term is standard normal.
#'
#' ### `method = "van_der_laan_2007_2"`
#'
#' This is another regression simulation from van der Laan et al. (2007)  with
#' twenty Gaussians with mean zero and variance 16. The prediction equation is:
#'
#' \preformatted{
#'   predictor_01 * predictor_02 + predictor_10^2 - predictor_03 * predictor_17 -
#'     predictor_15 * predictor_04 + predictor_09 * predictor_05 + predictor_19 -
#'     predictor_20^2 + predictor_09 * predictor_08
#' }
#'
#' The error term is also Gaussian with mean zero and variance 16.
#'
#' ### `method = "hooker_2004"`
#'
#' Hooker (2004) and Sorokina _at al_ (2008) used the following:
#'
#' \preformatted{
#'     pi ^ (predictor_01 * predictor_02) * sqrt( 2 * predictor_03 ) -
#'     asin(predictor_04) + log(predictor_03  + predictor_05) -
#'    (predictor_09 / predictor_10) * sqrt (predictor_07 / predictor_08) -
#'     predictor_02 * predictor_07
#' }
#'
#' Predictors 1, 2, 3, 6, 7, and 9 are standard uniform while the others are
#' uniform on `[0.6, 1.0]`. The errors are normal with mean zero and default
#' standard deviation of 0.25.
#'
#' ### `method = "worley_1987"`
#'
#' The simulation system from Worley (1987) is based on a mechanistic model for
#' the flow rate of liquids from two aquifers positioned vertically (i.e.,
#' the "upper" and "lower" aquifers). There are two sets of predictors:
#'
#'  - the borehole radius (`radius_borehole` from 0.05 to 0.15) and length
#'    (`length_borehole` from 1,120 to 1,680) .
#' - The radius of effect that the system has on collecting water
#'    (`radius_influence` from 100 to 50,000)
#'
#' and physical properties:
#'
#' -  `transmissibility_upper_aq`
#' -  `potentiometric_upper_aq`
#' -  `transmissibility_lower_aq`
#' -  `potentiometric_lower_aq`
#' -  `conductivity_borehole`
#'
#' A multiplicative error structure is used; the mechanistic equation is
#' multiplied by an exponentiated Gaussian random error.
#'
#' The references give feasible ranges for each of these variables. See also
#' Morris _et al_ (1993).
#'
#' ## `sim_noise()`
#'
#' This function simulates a number of random normal variables with mean zero.
#' The values can be independent if `cov_param = 0`. Otherwise the values are
#' multivariate normal with non-diagonal covariance matrices. For
#' `cov_type = "exchangeable"`, the structure has unit variances and covariances
#' of `cov_param`. With `cov_type = "toeplitz"`, the covariances have an
#' exponential pattern (see example below).
#'
#' ## Logistic simulation
#'
#' `sim_logistic()` provides a flexible interface to simulating a logistic
#' regression model with two multivariate normal variables `A` and `B` (with
#' zero mean, unit variances and correlation determined by the `correlation`
#' argument).
#'
#' For example, using `eqn = A + B` would specify that the true probability of
#' the event was
#'
#' \preformatted{
#'    prob = 1 / (1 + exp(A + B))
#' }
#'
#' The class levels for the outcome column are `"one"` and `"two"`.
#'
#' ## Multinomial simulation
#'
#' `sim_multinomial()` can generate data with classes `"one"`, `"two"`, and
#' `"three"` based on the values in arguments `eqn_1`, `eqn_2`, and `eqn_3`,
#' respectfully. Like [sim_logistic()] these equations use predictors `A` and
#' `B`.
#'
#' The individual equations are evaluated and exponentiated. After this, their
#' values are, for each row of data, normalized to add up to one. These
#' probabilities are them passed to [stats::rmultinom()] to generate the outcome
#' values.
#'
#' @references
#' Hooker, G. (2004, August). Discovering additive structure in black box
#' functions. In _Proceedings of the tenth ACM SIGKDD international conference
#' on Knowledge discovery and data mining_ (pp. 575-580).
#' DOI: 10.1145/1014052.1014122
#'
#' Morris, M. D., Mitchell, T. J., and Ylvisaker, D. (1993). Bayesian design
#' and analysis of computer experiments: use of derivatives in surface
#' prediction. _Technometrics_, 35(3), 243-255.
#'
#' Sapp, S., van der Laan, M. J., and Canny, J. (2014). Subsemble: an ensemble
#' method for combining subset-specific algorithm fits. _Journal of applied
#' statistics_, 41(6), 1247-1259. DOI: 10.1080/02664763.2013.864263
#'
#' Sorokina, D., Caruana, R., Riedewald, M., and Fink, D. (2008, July). Detecting
#' statistical interactions with additive groves of trees. In _Proceedings of
#' the 25th international conference on Machine learning_ (pp. 1000-1007).
#' DOI: 10.1145/1390156.1390282
#'
#' Van der Laan, M. J., Polley, E. C., and Hubbard, A. E. (2007). Super learner.
#' _Statistical applications in genetics and molecular biology_, 6(1).
#' DOI: 10.2202/1544-6115.1309.
#'
#' Worley, B. A. (1987). Deterministic uncertainty analysis (No. ORNL-6428). Oak
#' Ridge National Lab.(ORNL), Oak Ridge, TN/
#'
#'
#' @examples
#' set.seed(1)
#' sim_regression(100)
#' sim_classification(100)
#'
#' # Flexible logistic regression simulation
#' if (rlang::is_installed("ggplot2")) {
#'   library(dplyr)
#'   library(ggplot2)
#'
#'   sim_logistic(1000, ~ .1 + 2 * A - 3 * B + 1 * A *B, corr = .7) |>
#'     ggplot(aes(A, B, col = class)) +
#'     geom_point(alpha = 1/2) +
#'     coord_equal()
#'
#'   f_xor <- ~ 10 * xor(A > 0, B < 0)
#'   # or
#'   f_xor <- rlang::expr(10 * xor(A > 0, B < 0))
#'
#'   sim_logistic(1000, f_xor, keep_truth = TRUE) |>
#'     ggplot(aes(A, B, col = class)) +
#'     geom_point(alpha = 1/2) +
#'     coord_equal() +
#'     theme_bw()
#' }
#'
#' ## How to use external symbols:
#'
#' a_coef <- 2
#' # splice the value in using rlang's !! operator
#' lp_eqn <- rlang::expr(!!a_coef * A+B)
#' lp_eqn
#' sim_logistic(5, lp_eqn)
#'
#' # Flexible multinomial regression simulation
#' if (rlang::is_installed("ggplot2")) {
#'
#   set.seed(2)
#   three_classes <-
#     sim_multinomial(
#       1000,
#       ~  -0.5    +  0.6 * abs(A),
#       ~ ifelse(A > 0 & B > 0, 1.0 + 0.2 * A / B, - 2),
#       ~ -0.6 * A + 0.50 * B -  A * B)
#
#   three_classes |>
#     ggplot(aes(A, B, col = class, pch = class)) +
#     geom_point(alpha = 3/4) +
#     facet_wrap(~ class) +
#     coord_equal() +
#     theme_bw()
#' }
#' @export
sim_classification <- function(
  num_samples = 100,
  method = "caret",
  intercept = -5,
  num_linear = 10,
  keep_truth = FALSE
) {
  method <- rlang::arg_match0(method, "caret", arg_nm = "method")
  check_number_whole(num_samples, min = 1)
  check_number_whole(num_linear, min = 0)
  check_number_decimal(intercept)
  check_single_logical(keep_truth)


  if (method == "caret") {
    # Simulate two correlated normal variates
    var_cov <- matrix(c(2, 1.3, 1.3, 2), 2, 2)
    dat <- MASS::mvrnorm(n = num_samples, c(0, 0), var_cov)

    # Simulate a uniform for the first nonlinear term
    dat <- cbind(dat, stats::runif(num_samples, min = -1))
    # Simulate second two nonlinear terms
    dat <- cbind(dat, matrix(stats::runif(num_samples * 2), ncol = 2))

    # Assign names
    colnames(dat) <- c(paste0("two_factor_", 1:2), paste0("non_linear_", 1:3))

    linear_pred <-
      rlang::expr(
        !!intercept -
          4 * two_factor_1 +
          4 * two_factor_2 +
          2 * two_factor_1 * two_factor_2 +
          (non_linear_1^3) +
          2 * exp(-6 * (non_linear_1 - 0.3)^2) +
          2 * sin(pi * non_linear_2 * non_linear_3)
      )

    # Simulate a series of linear coefficients
    if (num_linear > 0) {
      dat_linear <- matrix(
        stats::rnorm(num_samples * num_linear),
        ncol = num_linear
      )
      lin_names <- names0(num_linear, "linear_")
      colnames(dat_linear) <- lin_names
      lin_symbols <- rlang::syms(lin_names)
      lin_coefs <-
        seq(10, 1, length = num_linear) /
        4 *
        rep_len(c(-1, 1), length.out = num_linear)
      lin_expr <-
        purrr::map2(lin_coefs, lin_symbols, ~ rlang::expr(!!.x * !!.y)) |>
        purrr::reduce(function(l, r) rlang::expr(!!l + !!r))
      .truth <- rlang::expr(!!linear_pred + !!lin_expr)
      dat <- cbind(dat, dat_linear)
    }
  }

  dat <- tibble::as_tibble(dat)

  dat <-
    dat |>
    dplyr::mutate(
      linear_pred = rlang::eval_tidy(linear_pred, data = dat),
      .truth = stats::binomial()$linkinv(linear_pred),
      rand = stats::runif(num_samples),
      class = ifelse(rand <= .truth, "class_1", "class_2"),
      class = factor(class, levels = c("class_1", "class_2"))
    ) |>
    dplyr::select(-linear_pred, -rand) |>
    dplyr::relocate(class)

  if (!keep_truth) {
    dat <- dplyr::select(dat, -.truth)
  }

  dat
}

#' @export
#' @rdname sim_classification
sim_regression <-
  function(
    num_samples = 100,
    method = "sapp_2014_1",
    std_dev = NULL,
    factors = FALSE,
    keep_truth = FALSE
  ) {
    reg_methods <- c(
      "sapp_2014_1",
      "sapp_2014_2",
      "van_der_laan_2007_1",
      "van_der_laan_2007_2",
      "hooker_2004",
      "worley_1987"
    )
    method <- rlang::arg_match0(method, reg_methods, arg_nm = "method")
    check_number_whole(num_samples, min = 1)
    check_number_decimal(std_dev, allow_null = TRUE)
    check_single_logical(factors)
    check_single_logical(keep_truth)

    dat <-
      switch(
        method,
        sapp_2014_1 = sapp_2014_1(num_samples, std_dev),
        sapp_2014_2 = sapp_2014_2(num_samples, std_dev),
        van_der_laan_2007_1 = van_der_laan_2007_1(
          num_samples,
          std_dev,
          factors = factors
        ),
        van_der_laan_2007_2 = van_der_laan_2007_2(num_samples, std_dev),
        hooker_2004 = hooker_2004(num_samples, std_dev),
        worley_1987 = worley_1987(num_samples, std_dev)
      )

    if (!keep_truth) {
      dat <- dplyr::select(dat, -.truth)
    }

    dat
  }


sapp_2014_1 <- function(num_samples = 100, std_dev = NULL) {
  if (is.null(std_dev)) {
    std_dev <- 3
  }
  dat <- matrix(stats::rnorm(num_samples * 20, sd = 3), ncol = 20)
  colnames(dat) <- names0(20, "predictor_")
  dat <- tibble::as_tibble(dat)

  slc_14 <- rlang::expr(
    predictor_01 +
      sin(predictor_02) +
      log(abs(predictor_03)) +
      predictor_04^2 +
      predictor_05 * predictor_06 +
      ifelse(predictor_07 * predictor_08 * predictor_09 < 0, 1, 0) +
      ifelse(predictor_10 > 0, 1, 0) +
      predictor_11 * ifelse(predictor_11 > 0, 1, 0) +
      sqrt(abs(predictor_12)) +
      cos(predictor_13) +
      2 * predictor_14 +
      abs(predictor_15) +
      ifelse(predictor_16 < -1, 1, 0) +
      predictor_17 * ifelse(predictor_17 < -1, 1, 0) -
      2 * predictor_18 -
      predictor_19 * predictor_20
  )

  dat <-
    dat |>
    dplyr::mutate(
      .truth = rlang::eval_tidy(slc_14, data = dat),
      outcome = .truth + stats::rnorm(num_samples, sd = std_dev)
    ) |>
    dplyr::relocate(outcome)

  dat
}

sapp_2014_2 <- function(num_samples = 100, std_dev = 4) {
  if (is.null(std_dev)) {
    std_dev <- 5
  }
  dat <- matrix(stats::rnorm(num_samples * 200, sd = 4), ncol = 200)
  colnames(dat) <- names0(200, "predictor_")

  slc_14 <- function(x) sum(log(abs(x)))

  .truth <- apply(dat, 1, slc_14)
  y <- .truth + stats::rnorm(num_samples, sd = std_dev) - 1
  dat <- tibble::as_tibble(dat)
  dat$outcome <- y
  dat$.truth <- .truth
  dplyr::relocate(dat, outcome)
}

van_der_laan_2007_1 <- function(
  num_samples = 100,
  std_dev = NULL,
  factors = FALSE
) {
  if (is.null(std_dev)) {
    std_dev <- 1
  }
  dat <- matrix(stats::rbinom(num_samples * 10, size = 1, prob = .4), ncol = 10)
  colnames(dat) <- names0(10, "predictor_")
  dat <- tibble::as_tibble(dat)

  lph_07 <- rlang::expr(
    2 *
      predictor_01 *
      predictor_10 +
      4 * predictor_02 * predictor_07 +
      3 * predictor_04 * predictor_05 -
      5 * predictor_06 * predictor_10 +
      3 * predictor_08 * predictor_09 +
      predictor_01 * predictor_02 * predictor_04 -
      2 * predictor_07 * (1 - predictor_06) * predictor_02 * predictor_09 -
      4 * (1 - predictor_10) * predictor_01 * (1 - predictor_04)
  )

  dat <-
    dat |>
    dplyr::mutate(
      .truth = rlang::eval_tidy(lph_07, data = dat),
      outcome = .truth + stats::rnorm(num_samples, sd = std_dev)
    ) |>
    dplyr::relocate(outcome)

  if (factors) {
    dat <-
      dat |>
      dplyr::mutate(
        dplyr::across(2:11, ~ ifelse(.x == 1, "yes", "no")),
        dplyr::across(2:11, ~ factor(.x, levels = c("yes", "no")))
      )
  }

  dat
}

van_der_laan_2007_2 <- function(num_samples = 100, std_dev = NULL) {
  if (is.null(std_dev)) {
    std_dev <- 4
  }
  dat <- matrix(stats::rnorm(num_samples * 20, sd = 4), ncol = 20)
  colnames(dat) <- names0(20, "predictor_")
  dat <- tibble::as_tibble(dat)

  lph_07 <- rlang::expr(
    predictor_01 *
      predictor_02 +
      predictor_10^2 -
      predictor_03 * predictor_17 -
      predictor_15 * predictor_04 +
      predictor_09 * predictor_05 +
      predictor_19 -
      predictor_20^2 +
      predictor_09 * predictor_08
  )

  dat <-
    dat |>
    dplyr::mutate(
      .truth = rlang::eval_tidy(lph_07, data = dat),
      outcome = .truth + stats::rnorm(num_samples, sd = std_dev)
    ) |>
    dplyr::relocate(outcome)

  dat
}

# TODO see table 1 of Detecting Statistical Interactions from Neural Network Weights for more
hooker_2004 <- function(num_samples = 100, std_dev = NULL) {
  if (is.null(std_dev)) {
    std_dev <- 1 / 4
  }
  uni_1 <- matrix(stats::runif(num_samples * 6), ncol = 6)
  uni_2 <- matrix(stats::runif(num_samples * 4, min = 0.6), ncol = 4)
  all_names <- names0(10, "predictor_")
  colnames(uni_1) <- all_names[c(1, 2, 3, 6, 7, 9)]
  colnames(uni_2) <- all_names[c(4, 5, 8, 10)]
  dat <- cbind(uni_1, uni_2)
  dat <- tibble::as_tibble(dat) |> dplyr::select(dplyr::all_of(all_names))

  hooker_2004 <- rlang::expr(
    pi^(predictor_01 * predictor_02) *
      sqrt(2 * predictor_03) -
      asin(predictor_04) +
      log(predictor_03 + predictor_05) -
      (predictor_09 / predictor_10) * sqrt(predictor_07 / predictor_08) -
      predictor_02 * predictor_07
  )

  dat <-
    dat |>
    dplyr::mutate(
      .truth = rlang::eval_tidy(hooker_2004, data = dat),
      outcome = .truth + stats::rnorm(num_samples, sd = std_dev)
    ) |>
    dplyr::relocate(outcome)

  dat
}

worley_1987 <- function(num_samples = 100, std_dev = 0.25) {
  if (is.null(std_dev)) {
    std_dev <- 0.25
  }
  radius_borehole <- runif(num_samples, min = 0.05, max = 0.15)
  length_borehole <- runif(num_samples, min = 1120, max = 1680)
  radius_influence <- 10^runif(num_samples, min = 2, max = log10(50000))
  transmissibility_upper_aq <- 10^runif(
    num_samples,
    min = log10(63070),
    max = log10(115600)
  )
  potentiometric_upper_aq <- runif(num_samples, min = 990, max = 1110)
  transmissibility_lower_aq <- runif(num_samples, min = 63.1, max = 116)
  potentiometric_lower_aq <- runif(num_samples, min = 700, max = 820)
  # conductivity_borehole <- runif(num_samples, min = 9855, max = 12045)
  # expanded range from Moriss at al
  conductivity_borehole <- 10^runif(
    num_samples,
    min = log10(1500),
    max = log10(15000)
  )

  numer <- 2 *
    pi *
    transmissibility_upper_aq *
    (potentiometric_upper_aq - potentiometric_lower_aq)

  denom_1 <- log(radius_influence / radius_borehole)

  denom_2 <- 2 *
    length_borehole *
    transmissibility_upper_aq /
    (denom_1 * radius_borehole^2 * conductivity_borehole)

  denom_3 <- transmissibility_upper_aq / transmissibility_lower_aq

  error <- exp(rnorm(num_samples, mean = 0, sd = std_dev))

  tibble::tibble(
    .truth = numer / (denom_1 * (1 + denom_2 + denom_3)),
    outcome = .truth * error,
    radius_borehole = radius_borehole,
    length_borehole = length_borehole,
    radius_influence = radius_influence,
    transmissibility_upper_aq = transmissibility_upper_aq,
    potentiometric_upper_aq = potentiometric_upper_aq,
    transmissibility_lower_aq = transmissibility_lower_aq,
    potentiometric_lower_aq = potentiometric_lower_aq,
    conductivity_borehole = conductivity_borehole
  )
}

# ------------------------------------------------------------------------------

#' @export
#' @rdname sim_classification
sim_noise <- function(
  num_samples,
  num_vars,
  cov_type = "exchangeable",
  outcome = "none",
  num_classes = 2,
  cov_param = 0
) {
  cov_type <- rlang::arg_match0(
    cov_type,
    c("exchangeable", "toeplitz"),
    arg_nm = "cov_type"
  )
  outcome <- rlang::arg_match0(
    outcome,
    c("none", "classification", "regression"),
    arg_nm = "outcome"
  )

  check_number_whole(num_samples, min = 1)
  check_number_whole(num_vars, min = 1)
  check_number_whole(num_classes, min = 2)
  check_number_decimal(cov_param)

  if (cov_type == "exchangeable") {
    var_cov <- matrix(cov_param, ncol = num_vars, nrow = num_vars)
    diag(var_cov) <- 1
  } else {
    var_cov_values <- cov_param^(seq(0, num_vars - 1, by = 1))
    var_cov <- stats::toeplitz(var_cov_values)
  }
  dat <- MASS::mvrnorm(num_samples, mu = rep(0, num_vars), Sigma = var_cov)
  colnames(dat) <- names0(num_vars, "noise_")
  dat <- tibble::as_tibble(dat)

  if (outcome == "classification") {
    cls <- names0(num_classes, "class_")
    dat <-
      dat |>
      dplyr::mutate(
        class = sample(cls, num_samples, replace = TRUE),
        class = factor(class, levels = cls)
      ) |>
      dplyr::relocate(class)
  } else if (outcome == "regression") {
    dat <-
      dat |>
      dplyr::mutate(outcome = stats::rnorm(num_samples)) |>
      dplyr::relocate(outcome)
  }
  dat
}

# ------------------------------------------------------------------------------

#' @export
#' @rdname sim_classification
sim_logistic <- function(
  num_samples,
  eqn,
  correlation = 0,
  keep_truth = FALSE
) {
  check_number_whole(num_samples, min = 1)
  check_number_decimal(correlation)
  check_single_logical(keep_truth)

  sigma <- matrix(c(1, correlation, correlation, 1), 2, 2)
  eqn <- rlang::get_expr(eqn)
  check_equations(eqn)
  dat <-
    data.frame(MASS::mvrnorm(n = num_samples, c(0, 0), sigma)) |>
    stats::setNames(LETTERS[1:2]) |>
    tibble::as_tibble()

  dat <-
    dat |>
    dplyr::mutate(
      .linear_pred = rlang::eval_tidy(eqn, data = dat),
      .linear_pred = as.numeric(.linear_pred),
      .truth = stats::binomial()$linkinv(.linear_pred),
      .rand = stats::runif(num_samples),
      class = ifelse(.rand <= .truth, "one", "two"),
      class = factor(class, levels = c("one", "two"))
    ) |>
    dplyr::select(-.rand) |>
    tibble::as_tibble()

  if (!keep_truth) {
    dat <- dat |> dplyr::select(-.truth, -.linear_pred)
  }
  dat
}

# ------------------------------------------------------------------------------

#' @export
#' @rdname sim_classification
sim_multinomial <- function(
  num_samples,
  eqn_1,
  eqn_2,
  eqn_3,
  correlation = 0,
  keep_truth = FALSE
) {
  check_number_whole(num_samples, min = 1)
  check_number_decimal(correlation)
  check_single_logical(keep_truth)

  sigma <- matrix(c(1, correlation, correlation, 1), 2, 2)
  eqn_1 <- rlang::get_expr(eqn_1)
  eqn_2 <- rlang::get_expr(eqn_2)
  eqn_3 <- rlang::get_expr(eqn_3)
  purrr::map_lgl(list(eqn_1, eqn_2, eqn_3), check_equations)

  dat <- data.frame(MASS::mvrnorm(n = num_samples, c(0, 0), sigma)) |>
    stats::setNames(LETTERS[1:2]) |>
    tibble::as_tibble()

  dat <-
    dat |>
    dplyr::mutate(
      .formula_1 = rlang::eval_tidy(eqn_1, data = dat),
      .formula_2 = rlang::eval_tidy(eqn_2, data = dat),
      .formula_3 = rlang::eval_tidy(eqn_3, data = dat),
      dplyr::across(c(dplyr::starts_with(".formula_")), ~ exp(.x))
    )
  probs <- as.matrix(dplyr::select(dat, dplyr::starts_with(".formula_")))
  probs <- t(apply(probs, 1, function(x) x / sum(x)))
  which_class <- function(x) which.max(stats::rmultinom(1, 1, x))
  index <- apply(probs, 1, which_class)
  lvls <- c("one", "two", "three")
  dat$class <- factor(lvls[index], levels = lvls)
  dat <- dat |> dplyr::select(-dplyr::starts_with(".formula_"))
  if (keep_truth) {
    colnames(probs) <- paste0(".truth_", lvls)
    probs <- tibble::as_tibble(probs)
    dat <- dplyr::bind_cols(dat, probs)
  }
  tibble::as_tibble(dat)
}

# ------------------------------------------------------------------------------

check_equations <- function(x, expected = LETTERS[1:2]) {
  used <- sort(all.vars(x))
  its_fine <- length(setdiff(used, expected)) == 0
  if (!its_fine) {
    cli::cli_abort("The model equations should only use variables/objects
                   {.code A} and {.code B}.")
  }
  invisible(its_fine)
}

names0 <- function(num, prefix = "x") {
  if (num < 1) {
    cli::cli_abort("{.arg num} should be > 0")
  }
  ind <- format(1:num)
  ind <- gsub(" ", "0", ind)
  paste0(prefix, ind)
}

check_single_logical <- function(x, call = rlang::caller_env()) {
  cl <- match.call()
  arg_nm <- as.character(cl$x)
  msg <- "{.arg {arg_nm}} should be a single logical value, not {obj_type_friendly(x)}."
  if (!is.logical(x)) {
    cli::cli_abort(msg, call = call)
  }
  if (length(x) > 1 || any(is.na(x))) {
    cli::cli_abort(msg, call = call)
  }
  invisible(x)
}

test_that("classification simulation", {
  set.seed(1)
  dat_1 <- sim_classification(500, num_linear = 0)
  dat_2 <- sim_classification(10, num_linear = 11)
  dat_3 <- sim_classification(1000, num_linear = 1, intercept = 50)
  dat_4 <- sim_classification(500, num_linear = 0, keep_truth = TRUE)

  expect_equal(
    names(dat_1),
    c(
      "class",
      "two_factor_1",
      "two_factor_2",
      "non_linear_1",
      "non_linear_2",
      "non_linear_3"
    )
  )
  expect_equal(
    names(dat_2),
    c(
      "class",
      "two_factor_1",
      "two_factor_2",
      "non_linear_1",
      "non_linear_2",
      "non_linear_3",
      modeldata:::names0(11, "linear_")
    )
  )
  expect_equal(
    names(dat_3),
    c(
      "class",
      "two_factor_1",
      "two_factor_2",
      "non_linear_1",
      "non_linear_2",
      "non_linear_3",
      "linear_1"
    )
  )
  expect_equal(
    names(dat_4),
    c(
      "class",
      "two_factor_1",
      "two_factor_2",
      "non_linear_1",
      "non_linear_2",
      "non_linear_3",
      ".truth"
    )
  )
  expect_equal(nrow(dat_1), 500)
  expect_equal(nrow(dat_2), 10)
  expect_equal(nrow(dat_3), 1000)
  expect_true(all(vapply(dat_1[, -1], is.numeric, logical(1))))

  expect_equal(sum(dat_3 == "class_2"), 0)
  expect_equal(levels(dat_3$class), paste0("class_", 1:2))
  expect_snapshot(
    sim_classification(5, method = "potato"),
    error = TRUE
  )
  expect_snapshot(
    sim_classification(500, num_linear = -1),
    error = TRUE
  )
  expect_snapshot(
    sim_classification(-1),
    error = TRUE
  )
  expect_snapshot(
    sim_classification(1, intercept = NA),
    error = TRUE
  )
  expect_snapshot(
    sim_classification(1, keep_truth = NA),
    error = TRUE
  )
  expect_snapshot(
    error = TRUE,
    sim_classification(5, method = "potato")
  )
})

test_that("sapp_2014_1 simulation", {
  set.seed(1)
  dat_1 <- sim_regression(10, method = "sapp_2014_1")
  dat_2 <- sim_regression(10, method = "sapp_2014_1", keep_truth = TRUE)
  expect_equal(names(dat_1), c("outcome", modeldata:::names0(20, "predictor_")))
  expect_equal(
    names(dat_2),
    c("outcome", modeldata:::names0(20, "predictor_"), ".truth")
  )
  expect_equal(nrow(dat_1), 10)
  expect_true(all(vapply(dat_1, is.numeric, logical(1))))
  expect_snapshot(
    sim_regression(5, method = "potato"),
    error = TRUE
  )
})

test_that("sapp_2014_2 simulation", {
  set.seed(1)
  dat_1 <- sim_regression(10, method = "sapp_2014_2")
  dat_2 <- sim_regression(10, method = "sapp_2014_2", keep_truth = TRUE)
  expect_equal(
    names(dat_1),
    c("outcome", modeldata:::names0(200, "predictor_"))
  )
  expect_equal(
    names(dat_2),
    c("outcome", modeldata:::names0(200, "predictor_"), ".truth")
  )
  expect_equal(nrow(dat_1), 10)
  expect_true(all(vapply(dat_1, is.numeric, logical(1))))
})

test_that("van_der_laan_2007_1 simulation", {
  set.seed(1)
  dat_1 <- sim_regression(10, method = "van_der_laan_2007_1")
  dat_2 <- sim_regression(10, method = "van_der_laan_2007_1", factors = TRUE)
  dat_3 <- sim_regression(10, method = "van_der_laan_2007_1", keep_truth = TRUE)
  expect_equal(names(dat_1), c("outcome", modeldata:::names0(10, "predictor_")))
  expect_equal(
    names(dat_3),
    c("outcome", modeldata:::names0(10, "predictor_"), ".truth")
  )
  expect_equal(nrow(dat_1), 10)
  expect_true(all(vapply(dat_1, is.numeric, logical(1))))
  expect_true(all(vapply(dat_1[, -1], is.integer, logical(1))))
  expect_true(all(vapply(dat_2[, -1], is.factor, logical(1))))
  expect_equal(levels(dat_2$predictor_01), c("yes", "no"))
})

test_that("van_der_laan_2007_2 simulation", {
  set.seed(1)
  dat_1 <- sim_regression(10, method = "van_der_laan_2007_2")
  dat_2 <- sim_regression(10, method = "van_der_laan_2007_2", keep_truth = TRUE)
  expect_equal(names(dat_1), c("outcome", modeldata:::names0(20, "predictor_")))
  expect_equal(
    names(dat_2),
    c("outcome", modeldata:::names0(20, "predictor_"), ".truth")
  )
  expect_equal(nrow(dat_1), 10)
  expect_true(all(vapply(dat_1, is.numeric, logical(1))))
})

test_that("hooker_2004 simulation", {
  set.seed(1)
  dat_1 <- sim_regression(10, method = "hooker_2004")
  dat_2 <- sim_regression(10, method = "hooker_2004", keep_truth = TRUE)
  expect_equal(names(dat_1), c("outcome", modeldata:::names0(10, "predictor_")))
  expect_equal(
    names(dat_2),
    c("outcome", modeldata:::names0(10, "predictor_"), ".truth")
  )
  expect_equal(nrow(dat_1), 10)
  expect_true(all(vapply(dat_1, is.numeric, logical(1))))
})


test_that("noise simulation", {
  set.seed(1)
  dat_1 <- sim_noise(1000, num_vars = 10)
  dat_2 <- sim_noise(1000, num_vars = 3, cov_param = .5)
  dat_3 <- sim_noise(1000, num_vars = 3, cov_type = "toeplitz", cov_param = .99)
  dat_4 <- sim_noise(10, num_vars = 3, outcome = "classification")
  dat_5 <- sim_noise(
    10,
    num_vars = 3,
    outcome = "classification",
    num_classes = 10
  )
  dat_6 <- sim_noise(10, num_vars = 3, outcome = "regression")

  expect_equal(names(dat_1), modeldata:::names0(10, "noise_"))
  expect_equal(names(dat_2), modeldata:::names0(3, "noise_"))
  expect_equal(nrow(dat_1), 1000)
  expect_equal(nrow(dat_4), 10)

  expect_true(all(vapply(dat_1, is.numeric, logical(1))))
  expect_true(all(vapply(dat_1[, -1], is.numeric, logical(1))))
  expect_true(is.factor(dat_5$class))
  expect_true(all(vapply(dat_6, is.numeric, logical(1))))

  cor_1 <- cor(dat_1)[upper.tri(cor(dat_1))]
  expect_true(all(cor_1 <= 0.1 & cor_1 >= -0.1))

  cor_2 <- cor(dat_2)[upper.tri(cor(dat_2))]
  expect_true(all(cor_2 <= 0.6 & cor_2 >= 0.4))

  cor_3 <- cor(dat_3)[upper.tri(cor(dat_3))]
  expect_true(all(cor_3 >= 0.95))

  expect_equal(levels(dat_4$class), paste0("class_", 1:2))
  expect_equal(levels(dat_5$class), modeldata:::names0(10, "class_"))

  expect_snapshot(
    sim_noise(5, cov_type = "potato"),
    error = TRUE
  )
  expect_snapshot(
    sim_noise(5, outcome = "potato"),
    error = TRUE
  )
  expect_snapshot(
    sim_noise(num_vars, num_linear = -1),
    error = TRUE
  )
  expect_snapshot(
    sim_noise(-1),
    error = TRUE
  )
  expect_snapshot(
    sim_noise(1, num_classes = 1),
    error = TRUE
  )
  expect_snapshot(
    sim_noise(1, cov_param = NA),
    error = TRUE
  )
})


test_that("logistic simulation", {
  set.seed(1)
  dat_1 <- sim_logistic(10, ~A)
  dat_2 <- sim_logistic(10, rlang::expr(~B), keep_truth = TRUE)
  expect_equal(names(dat_1), c(LETTERS[1:2], "class"))
  expect_equal(names(dat_2), c(LETTERS[1:2], ".linear_pred", ".truth", "class"))
  expect_equal(nrow(dat_1), 10)


  expect_snapshot(
    sim_logistic(10, ~ A, correlation = NA),
    error = TRUE
  )
  expect_snapshot(
    sim_logistic(-1),
    error = TRUE
  )
  expect_snapshot(
    sim_logistic(10, ~ A, keep_truth = 1),
    error = TRUE
  )

})


test_that("multinomial simulation", {
  expect_snapshot_error(sim_multinomial(10, ~ A + C, ~B, ~ A + B))
  set.seed(1)
  dat_1 <- sim_multinomial(10, ~A, ~B, ~ A + B)
  dat_2 <- sim_multinomial(10, ~A, ~B, ~ A + B, keep_truth = TRUE)
  expect_equal(names(dat_1), c(LETTERS[1:2], "class"))
  expect_equal(
    names(dat_2),
    c(LETTERS[1:2], "class", ".truth_one", ".truth_two", ".truth_three")
  )
  expect_equal(nrow(dat_1), 10)

  expect_snapshot(
    sim_multinomial(10, ~ A, correlation = NA),
    error = TRUE
  )
  expect_snapshot(
    sim_multinomial(-1),
    error = TRUE
  )
  expect_snapshot(
    sim_multinomial(10, ~ A, keep_truth = 1),
    error = TRUE
  )
})

#' OkCupid data
#'
#' These are a sample of columns of users of OkCupid dating website. The data
#' are from Kim and Escobedo-Land (2015). Permission to use this data set was
#' explicitly granted by OkCupid.
#'
#' @name okc
#' @aliases okc
#' @docType data
#' @return \item{okc}{a data frame}
#'
#' @source Kim, A. Y., and A. Escobedo-Land. 2015. "OkCupid Data for
#'   Introductory Statistics and Data Science Courses." *Journal of
#'   Statistics Education: An International Journal on the Teaching and
#'   Learning of Statistics*.
#'
#' @keywords datasets
#' @examples
#' data(okc)
#' str(okc)
NULL

#' Annual Stack Overflow Developer Survey Data
#'
#' @details These data are a collection of 5,594 data points collected on
#' developers. These data could be used to try to predict who works remotely
#' (as used in the source listed below).
#'
#' @name stackoverflow
#' @aliases stackoverflow
#' @docType data
#' @return \item{stackoverflow}{a tibble}
#'
#' @source
#' Julia Silge, _Supervised Machine Learning Case Studies in R_
#'
#' `https://supervised-ml-course.netlify.com/chapter2`
#'
#' Raw data: `https://insights.stackoverflow.com/survey/`
#' @keywords datasets
#' @examples
#' data(stackoverflow)
#' str(stackoverflow)
NULL

#' Smithsonian museums
#'
#' Geocodes for the Smithsonian museums (circa 2018).
#'
#' @name Smithsonian
#' @aliases Smithsonian
#' @docType data
#' @return \item{Smithsonian}{a tibble}
#'
#' @source https://en.wikipedia.org/wiki/List_of_Smithsonian_museums
#'
#' @keywords datasets
#' @examples
#' data(Smithsonian)
#' str(Smithsonian)
NULL

#' Rates of Cricket Chirps
#'
#' These data are from from McDonald (2009), by way of Mangiafico (2015), on
#' the relationship between the ambient temperature and the rate of cricket
#' chirps per minute. Data were collected for two species of the genus _Oecanthus_: _O. exclamationis_
#' and _O. niveus_. The data are contained in a data frame called `crickets` with
#' a total of 31 data points.
#'
#' @name crickets
#' @aliases crickets
#' @docType data
#' @return \item{crickets}{a tibble}
#' @source Mangiafico, S. 2015. "An R Companion for the Handbook of Biological
#' Statistics." \url{https://rcompanion.org/handbook/}.
#'
#' McDonald, J. 2009. _Handbook of Biological Statistics_. Sparky House Publishing.
#' @keywords datasets
#' @examples
#' data(crickets)
#' str(crickets)
NULL

#' Clinical data used to predict ischemic stroke
#'
#' @description
#' A data set to predict a binary outcome using imaging and patient data.
#'
#' @name ischemic_stroke
#' @aliases ischemic_stroke
#' @docType data
#' @return \item{ischemic_stroke}{a tibble}
#'
#' @details
#' These data were gathered to predict patient risk for ischemic stroke. A
#' historical set of patients with a range of carotid artery blockages were
#' selected. The data consisted of 126 patients, 44 of which had blockages
#' greater than 70%. All patients had undergone Computed Tomography Angiography
#' (CTA) to generate a detailed three-dimensional visualization and
#' characterization of the blockage. These images were then analyzed in order to
#' compute several features related to the disease, including: percent stenosis,
#' arterial wall thickness, and tissue characteristics such as lipid-rich
#' necrotic core and calcification.
#'
#' The group of patients in this study also had follow-up information on
#' whether or not a stroke occurred at a subsequent point in time. The data for
#' each patient also included commonly collected clinical characteristics for
#' risk of stroke such as whether or not the patient had atrial fibrillation,
#' coronary artery disease, and a history of smoking. Demographics of gender and
#' age were included as well. These readily available risk factors can be
#' thought of as another potentially useful predictor set that can be evaluated.
#' In fact, this set of predictors should be evaluated first to assess their
#' ability to predict stroke since these predictors are easy to collect, are
#' acquired at patient presentation, and do not require an expensive imaging
#' technique.
#'
#' Columns:
#' \itemize{
#'  \item \code{stroke}:  factor (levels: 'yes' and 'no')
#'  \item \code{nascet_scale}:  numeric
#'  \item \code{calc_vol}:  numeric
#'  \item \code{calc_vol_prop}:  numeric
#'  \item \code{matx_vol}:  numeric
#'  \item \code{matx_vol_prop}:  numeric
#'  \item \code{lrnc_vol}:  numeric
#'  \item \code{lrnc_vol_prop}:  numeric
#'  \item \code{max_calc_area}:  numeric
#'  \item \code{max_calc_area_prop}:  numeric
#'  \item \code{max_dilation_by_area}:  numeric
#'  \item \code{max_matx_area}:  numeric
#'  \item \code{max_matx_area_prop}:  numeric
#'  \item \code{max_lrnc_area}:  numeric
#'  \item \code{max_lrnc_area_prop}:  numeric
#'  \item \code{max_max_wall_thickness}:  numeric
#'  \item \code{max_remodeling_ratio}:  numeric
#'  \item \code{max_stenosis_by_area}:  numeric
#'  \item \code{max_wall_area}:  numeric
#'  \item \code{wall_vol}:  numeric
#'  \item \code{max_stenosis_by_diameter}:  numeric
#'  \item \code{age}:  integer
#'  \item \code{male}:  integer
#'  \item \code{smoking_history}:  integer
#'  \item \code{atrial_fibrillation}:  integer
#'  \item \code{coronary_artery_disease}:  integer
#'  \item \code{diabetes_history}:  integer
#'  \item \code{hypercholesterolemia_history}:  integer
#'  \item \code{hypertension_history}:  integer
#' }
#' @source
#' Kuhn, Max, and Kjell Johnson. _Feature Engineering and Selection: A Practical
#' Approach for Predictive Models_. Chapman and Hall/CRC, 2019.
#'
#' @examples
#' data(ischemic_stroke)
#' str(ischemic_stroke)
#'
NULL

#' Fatty acid composition of commercial oils
#'
#' Fatty acid concentrations of commercial oils were measured using gas
#' chromatography.  The data is used to predict the type of oil.  Note that
#' only the known oils are in the data set. Also, the authors state that there
#' are 95 samples of known oils. However, we count 96 in Table 1 (pgs.  33-35).
#'
#'
#' @name oils
#' @aliases oils
#' @docType data
#' @return \item{oils}{a tibble}
#' @source Brodnjak-Voncina et al. (2005). Multivariate data analysis in
#' classification of vegetable oils characterized by the content of fatty
#' acids, \emph{Chemometrics and Intelligent Laboratory Systems}, Vol.
#' 75:31-45.
#' @keywords datasets
#' @examples
#' data(oils)
#' str(oils)
NULL

#' Ames Housing Data
#'
#' A data set from De Cock (2011) has 82 fields were recorded for 2,930
#' properties in Ames IA. This version is copies from the `AmesHousing` package
#' but does not include a few quality columns that appear to be outcomes
#' rather than predictors.
#'
#' See this links for the sources below for more information as well as
#' `?AmesHousing::make_ames`.
#'
#' @includeRmd man/rmd/ames.md details
#'
#' @name ames
#' @aliases ames
#' @docType data
#' @return \item{ames}{a tibble}
#' @source De Cock, D. (2011). "Ames, Iowa: Alternative to the Boston Housing Data as an End of Semester Regression Project," \emph{Journal of Statistics Education},  Volume 19, Number 3.
#'
#' \url{https://jse.amstat.org/v19n3/decock/DataDocumentation.txt}
#'
#' \url{https://jse.amstat.org/v19n3/decock.pdf}
#' @keywords datasets
#' @examples
#' data(ames)
#' str(ames)
NULL

#' Predicting hepatic injury from chemical information
#'
#' @description
#' A quantitative structure-activity relationship (QSAR) data set to predict
#' when a molecule has risk associated with liver function.
#'
#' @name hepatic_injury_qsar
#' @aliases hepatic_injury_qsar
#' @docType data
#' @return \item{hepatic_injury_qsar}{a tibble}
#'
#' @details
#' This  data set was used to develop a model for predicting compounds'
#' probability of causing hepatic injury (i.e. liver damage). This data set
#' consisted of 281 unique compounds; 376 predictors were measured or computed
#' for each. The response was categorical (either "none", "mild", or "severe"),
#' and was highly unbalanced.
#'
#' This kind of response often occurs in pharmaceutical data because companies
#' steer away from creating molecules that have undesirable characteristics.
#' Therefore, well-behaved molecules often greatly outnumber undesirable
#' molecules. The predictors consisted of measurements from 184 biological
#' screens and 192 chemical feature predictors. The biological predictors
#' represent activity for each screen and take values between 0 and 10 with a
#' mode of 4. The chemical feature predictors represent counts of important
#' sub-structures as well as measures of physical properties that are thought to
#' be associated with hepatic injury.
#'
#' Columns:
#' \itemize{
#'  \item \code{class}:  ordered and factor (levels: 'none', 'mild', and 'severe')
#'  \item \code{bio_assay_001} - \code{bio_assay_184}:  numeric
#'  \item \code{chem_fp_001} - \code{chem_fp_192}:  numeric
#' }
#' @source
#' Kuhn, Max, and Kjell Johnson. _Applied predictive modeling_. New York:
#' Springer, 2013.
#'
#' @examples
#' data(hepatic_injury_qsar)
#' str(hepatic_injury_qsar)
#'
NULL

#' Liver pathology data
#'
#' @details These data have the results of a _x_-ray examination
#'  to determine whether liver is abnormal or not (in the `scan`
#'  column) versus the more extensive pathology results that
#'  approximate the truth (in `pathology`).
#'
#' @name pathology
#' @aliases pathology
#' @docType data
#' @return \item{pathology}{a data frame}
#'
#' @source Altman, D.G., Bland, J.M. (1994) ``Diagnostic tests 1:
#'  sensitivity and specificity,'' *British Medical Journal*,
#'  vol 308, 1552.
#'
#'
#' @keywords datasets
#' @examples
#' data(pathology)
#' str(pathology)
NULL

#' Class probability predictions
#'
#' @details This data frame contains the predicted classes and
#'  class probabilities for a linear discriminant analysis model fit
#'  to the HPC data set from Kuhn and Johnson (2013). These data are
#'  the assessment sets from a 10-fold cross-validation scheme. The
#'  data column columns for the true class (`obs`), the class
#'  prediction (`pred`) and columns for each class probability
#'  (columns `VF`, `F`, `M`, and `L`). Additionally, a column for
#'  the resample indicator is included.
#'
#' @name hpc_cv
#' @aliases hpc_cv
#' @docType data
#' @return \item{hpc_cv}{a data frame}
#'
#' @source Kuhn, M., Johnson, K. (2013) *Applied Predictive
#'  Modeling*, Springer
#'
#' @keywords datasets
#' @examples
#' data(hpc_cv)
#' str(hpc_cv)
NULL

#' Biomass data
#'
#' Ghugare et al (2014) contains a data set where different biomass fuels are
#' characterized by the amount of certain molecules (carbon, hydrogen, oxygen,
#' nitrogen, and sulfur) and the corresponding higher heating value (HHV).
#' These data are from their Table S.2 of the Supplementary Materials
#'
#' @name biomass
#' @aliases biomass
#' @docType data
#' @return \item{biomass}{a data frame}
#'
#' @source Ghugare, S. B., Tiwary, S., Elangovan, V., and Tambe, S. S. (2013).
#' Prediction of Higher Heating Value of Solid Biomass Fuels Using Artificial
#' Intelligence Formalisms. *BioEnergy Research*, 1-12.
#'
#' @keywords datasets
#' @examples
#' data(biomass)
#' str(biomass)
NULL

#' Job attrition
#'
#' @details These data are from the IBM Watson Analytics Lab.
#'  The website describes the data with \dQuote{Uncover the
#'  factors that lead to employee attrition and explore important
#'  questions such as \sQuote{show me a breakdown of distance
#'  from home by job role and attrition} or \sQuote{compare
#'  average monthly income by education and attrition}. This is a
#'  fictional data set created by IBM data scientists.}. There
#'  are 1470 rows.
#'
#' @name attrition
#' @aliases attrition
#' @docType data
#' @return \item{attrition}{a data frame}
#'
#' @source The IBM Watson Analytics Lab website https://www.ibm.com/communities/analytics/watson-analytics-blog/hr-employee-attrition/
#'
#'
#' @keywords datasets
#' @examples
#' data(attrition)
#' str(attrition)
NULL

#' Alzheimer's disease data
#'
#' @details
#' Craig-Schapiro et al. (2011) describe a clinical study of 333 patients,
#'  including some with mild (but well-characterized) cognitive impairment as
#'  well as healthy individuals. CSF samples were taken from all subjects. The
#'  goal of the study was to determine if subjects in the early states of
#'  impairment could be differentiated from cognitively healthy individuals.
#'  Data collected on each subject included:
#' \itemize{
#' \item Demographic characteristics such as age and gender
#' \item Apolipoprotein E genotype
#' \item Protein measurements of Abeta, Tau, and a phosphorylated version of Tau (called pTau)
#' \item Protein measurements of 124 exploratory biomarkers, and
#' \item Clinical dementia scores
#' }
#'
#' For these analyses, we have converted the scores to two classes: impaired
#'  and healthy. The goal of this analysis is to create classification models
#'  using the demographic and assay data to predict which patients have early
#'  stages of disease.
#'
#' @name ad_data
#' @aliases ad_data
#' @docType data
#' @return \item{ad_data}{a tibble}
#'
#' @source
#' Kuhn, M., Johnson, K. (2013) *Applied Predictive Modeling*, Springer.
#'
#' Craig-Schapiro R, Kuhn M, Xiong C, Pickering EH, Liu J, Misko TP, et al.
#' (2011) Multiplexed Immunoassay Panel Identifies Novel CSF Biomarkers for
#' Alzheimer's Disease Diagnosis and Prognosis. PLoS ONE 6(4): e18850.
#'
#'
#' @keywords datasets
#' @examples
#' data(ad_data)
#' str(ad_data)
NULL

#' Predicting permeability from chemical information
#'
#' @description
#' A quantitative structure-activity relationship (QSAR) data set to predict
#' when a molecule can permeate cells.
#'
#' @name permeability_qsar
#' @aliases permeability_qsar
#' @docType data
#' @return \item{permeability_qsar}{a data frame}
#'
#' @details
#' This pharmaceutical data set was used to develop a model for predicting
#' compounds' permeability. In short, permeability is the measure of a
#' molecule's ability to cross a membrane. The body, for example, has notable
#' membranes between the body and brain, known as the blood-brain barrier, and
#' between the gut and body in the intestines. These membranes help the body
#' guard critical regions from receiving undesirable or detrimental substances.
#' For an orally taken drug to be effective in the brain, it first must pass
#' through the intestinal wall and then must pass through the blood-brain
#' barrier in order to be present for the desired neurological target.
#' Therefore, a compound's ability to permeate relevant biological membranes
#' is critically important to understand early in the drug discovery process.
#' Compounds that appear to be effective for a particular disease in research
#' screening experiments, but appear to be poorly permeable may need to be
#' altered in order improve permeability, and thus the compound's ability to
#' reach the desired target. Identifying permeability problems can help guide
#' chemists towards better molecules.
#'
#' Permeability assays such as PAMPA and Caco-2 have been developed to help
#' measure compounds' permeability (Kansy et al, 1998). These screens are
#' effective at quantifying a compound's permeability, but the assay is
#' expensive labor intensive. Given a sufficient number of compounds that have
#' been screened, we could develop a predictive model for permeability in an
#' attempt to potentially reduce the need for the assay. In this project there
#' were 165 unique compounds; 1107 molecular fingerprints were determined for
#' each. A molecular fingerprint is a binary sequence of numbers that
#' represents the presence or absence of a specific molecular sub-structure.
#' The response is highly skewed, the predictors are sparse (15.5% are present),
#' and many predictors are strongly associated.
#'
#' Columns:
#' \itemize{
#'   \item \code{permeability}: numeric
#'   \item \code{chem_fp_0001} - \code{chem_fp_1107}: numeric
#' }
#'
#' @source
#' Kuhn, Max, and Kjell Johnson. _Applied predictive modeling_. New York:
#' Springer, 2013.
#'
#' @examples
#' data(permeability_qsar)
#' str(permeability_qsar)
#'
NULL

#' Loan data
#'
#' @details These data were downloaded from the Lending Club
#'  access site (see below) and are from the first quarter of 2016.
#'  A subset of the rows and variables are included here. The
#'  outcome is in the variable `Class` and is either "good" (meaning
#'  that the loan was fully paid back or currently on-time) or "bad"
#'  (charged off, defaulted, of 21-120 days late). A data dictionary
#'  can be found on the source website.
#'
#' @name lending_club
#' @aliases lending_club
#' @docType data
#' @return \item{lending_club}{a data frame}
#'
#' @source Lending Club Statistics https://www.lendingclub.com/info/download-data.action
#'
#' @keywords datasets
#' @examples
#' data(lending_club)
#' str(lending_club)
NULL

#' High-performance computing system data
#'
#' Kuhn and Johnson (2013) describe a data set where characteristics of unix
#' jobs were used to classify there completion times as either very fast
#' (1 min or less, `VF`), fast (1–50 min, `F`), moderate (5–30 min, `M`), or
#' long (greater than 30 min, `L`).
#'
#'
#' @name hpc_data
#' @aliases hpc_data
#' @docType data
#' @return \item{hpc_data}{a tibble}
#' @keywords datasets
#' @source
#' Kuhn, M., Johnson, K. (2013) *Applied Predictive Modeling*, Springer.
#' @examples
#'
#' data(hpc_data)
#' str(hpc_data)
NULL

#' Fat, water and protein content of meat samples
#'
#' "These data are recorded on a Tecator Infratec Food and Feed Analyzer
#' working in the wavelength range 850 - 1050 nm by the Near Infrared
#' Transmission (NIT) principle. Each sample contains finely chopped pure meat
#' with different moisture, fat and protein contents.
#'
#' If results from these data are used in a publication we want you to mention
#' the instrument and company name (Tecator) in the publication.  In addition,
#' please send a preprint of your article to:
#'
#' Karin Thente, Tecator AB, Box 70, S-263 21 Hoganas, Sweden
#'
#' The data are available in the public domain with no responsibility from the
#' original data source. The data can be redistributed as long as this
#' permission note is attached."
#'
#' "For each meat sample the data consists of a 100 channel spectrum of
#' absorbances and the contents of moisture (water), fat and protein.  The
#' absorbance is -log10 of the transmittance measured by the spectrometer. The
#' three contents, measured in percent, are determined by analytic chemistry."
#'
#' Included here are the training, monitoring and test sets.
#'
#'
#' @name meats
#' @aliases meats
#' @docType data
#' @return \item{meats}{a tibble}
#' @keywords datasets
#' @examples
#'
#' data(meats)
#' str(meats)
NULL

#' Chicago taxi data set
#'
#' @description
#'
#' A data set containing information on a subset of taxi trips in the city
#' of Chicago in 2022.
#'
#' @name taxi
#' @aliases taxi
#' @docType data
#'
#' @return tibble
#'
#' @details
#'
#' The source data are originally described on the linked City of Chicago
#' data portal. The data exported here are a pre-processed subset motivated by
#' the modeling problem of predicting whether a rider will tip or not.
#'
#' \describe{
#'   \item{tip}{Whether the rider left a tip. A factor with levels
#'     "yes" and "no".}
#'   \item{distance}{The trip distance, in odometer miles.}
#'   \item{company}{The taxi company, as a factor. Companies that occurred
#'     few times were binned as "other".}
#'   \item{local}{Whether the trip's starting and ending locations are in the
#'     same community. See the source data for community area values.}
#'   \item{dow}{The day of the week in which the trip began, as a
#'     factor.}
#'   \item{month}{The month in which the trip began, as a factor.}
#'   \item{hour}{The hour of the day in which the trip began, as a
#'     numeric.}
#' }
#'
#' @source
#'
#' \url{https://data.cityofchicago.org/Transportation/Taxi-Trips/wrvz-psew}
#'
#' @examples
#' \donttest{
#' taxi
#' }
NULL

#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom stats rnorm runif
#' @import rlang
## usethis namespace: end
NULL


# needed for simulation docs
utils::globalVariables(
  c(
    ".",
    "linear_pred",
    "non_linear_1",
    "non_linear_2",
    "non_linear_3",
    "outcome",
    "predictor_01",
    "predictor_02",
    "predictor_03",
    "predictor_04",
    "predictor_05",
    "predictor_06",
    "predictor_07",
    "predictor_08",
    "predictor_09",
    "predictor_10",
    "predictor_11",
    "predictor_12",
    "predictor_13",
    "predictor_14",
    "predictor_15",
    "predictor_16",
    "predictor_17",
    "predictor_18",
    "predictor_19",
    "predictor_20",
    "rand",
    "true_prob",
    "two_factor_1",
    "two_factor_2",
    ".truth",
    ".linear_pred",
    ".rand"
  )
)

#' Morphometric data on scat
#'
#' Reid (2015) collected data on animal feses in coastal California. The data
#' consist of DNA verified species designations as well as fields related to
#' the time and place of the collection and the scat itself. The data are on
#' the three main species.
#'
#'
#' @name scat
#' @aliases scat
#' @docType data
#' @return \item{scat}{a tibble}
#' @source Reid, R. E. B. (2015). A morphometric modeling approach to
#' distinguishing among bobcat, coyote and gray fox scats. \emph{Wildlife
#' Biology}, 21(5), 254-262
#' @keywords datasets
#' @examples
#' data(scat)
#' str(scat)
NULL

#' Parkinson's disease speech classification data set
#'
#' @details From the UCI ML archive, the description is "The data used in this
#'  study were gathered from 188 patients with PD (107 men and 81 women) with
#'  ages ranging from 33 to 87 (65.1 p/m 10.9) at the Department of Neurology
#'  in Cerrahpaşa Faculty of Medicine, Istanbul University. The control group
#'  consists of 64 healthy individuals (23 men and 41 women) with ages varying
#'  between 41 and 82 (61.1 p/m 8.9). During the data collection process,
#'  the microphone is set to 44.1 KHz and following the physician's examination,
#'  the sustained phonation of the vowel `/a/` was collected from each subject
#'  with three repetitions."
#'
#'  The data here are averaged over the replicates.
#'
#' @name pd_speech
#' @aliases pd_speech
#' @docType data
#' @return \item{pd_speech}{a data frame}
#'
#' @source UCI ML repository (data) https://archive.ics.uci.edu/ml/datasets/Parkinson%27s+Disease+Classification#,
#'
#' Sakar et al (2019), "A comparative analysis of speech signal processing
#' algorithms for Parkinson’s disease classification and the use of the tunable
#' Q-factor wavelet transform", _Applied Soft Computing_, V74, pg 255-263.
#'
#' @keywords datasets
#' @examples
#' data(pd_speech)
#' str(pd_speech)
NULL

#' Compressive strength of concrete mixtures
#'
#' Yeh (2006) describes an aggregated data set for experimental designs used to
#' test the compressive strength of concrete mixtures. The data are used by
#' Kuhn and Johnson (2013).
#'
#'
#' @name concrete
#' @aliases concrete
#' @docType data
#' @return \item{concrete}{a tibble}
#' @keywords datasets
#' @source
#' Yeh I (2006). "Analysis of Strength of Concrete Using Design of Experiments
#' and Neural Networks." *Journal of Materials in Civil Engineering*, 18, 597-604.
#'
#' Kuhn, M., Johnson, K. (2013) *Applied Predictive Modeling*, Springer.
#' @examples
#' data(concrete)
#' str(concrete)
NULL

#' Watson churn data
#'
#' @details These data were downloaded from the IBM Watson site
#'  (see below) in September 2018. The data contain a factor for
#'  whether a customer churned or not. Alternatively, the `tenure`
#'  column presumably contains information on how long the customer
#'  has had an account. A survival analysis can be done on this
#'  column using the `churn` outcome as the censoring information. A
#'  data dictionary can be found on the source website.
#'
#' @name wa_churn
#' @aliases wa_churn
#' @docType data
#' @return \item{wa_churn}{a data frame}
#'
#' @source IBM Watson Analytics https://ibm.co/2sOvyvy
#'
#' @keywords datasets
#' @examples
#' data(wa_churn)
#' str(wa_churn)
NULL

#' Customer churn data
#'
#' A data set from the MLC++ machine learning software for modeling customer
#' churn. There are 19 predictors, mostly numeric: `state` (categorical),
#' `account_length` `area_code` `international_plan` (yes/no),
#' `voice_mail_plan` (yes/no), `number_vmail_messages`
#' `total_day_minutes` `total_day_calls` `total_day_charge`
#' `total_eve_minutes` `total_eve_calls` `total_eve_charge`
#' `total_night_minutes` `total_night_calls`
#' `total_night_charge` `total_intl_minutes`
#' `total_intl_calls` `total_intl_charge`, and
#' `number_customer_service_calls`.
#'
#' The outcome is contained in a column called `churn` (also yes/no).
#' A note in one of the source files states that the data are "artificial based
#' on claims similar to real world".
#'
#' @name mlc_churn
#' @aliases mlc_churn
#' @docType data
#' @return \item{mlc_churn}{a tibble}
#' @source Originally at `http://www.sgi.com/tech/mlc/`
#' @keywords datasets
#' @examples
#' data(mlc_churn)
#' str(mlc_churn)
NULL

#' Palmer Station penguin data
#'
#' A data set from Gorman, Williams, and Fraser (2014) containing measurements
#' from different types of penguins. This version of the data was retrieved from
#' Allison Horst's `palmerpenguins` package on 2020-06-22.
#'
#' @name penguins
#' @aliases penguins
#' @docType data
#' @return \item{penguins}{a tibble}
#' @source Gorman KB, Williams TD, Fraser WR (2014) Ecological Sexual Dimorphism
#' and Environmental Variability within a Community of Antarctic Penguins
#' (_Genus Pygoscelis_). PLoS ONE 9(3): e90081.
#' \doi{10.1371/journal.pone.0090081}
#'
#' \url{https://github.com/allisonhorst/palmerpenguins}
#' @keywords datasets
#' @examples
#' data(penguins)
#' str(penguins)
NULL

#' Two class data
#'
#' @details There are artificial data with two predictors (`A` and `B`) and
#'  a factor outcome variable (`Class`).
#'
#' @name two_class_dat
#' @aliases two_class_dat
#' @docType data
#' @return \item{two_class_dat}{a data frame}
#'
#' @keywords datasets
#' @examples
#' data(two_class_dat)
#' str(two_class_dat)
NULL

#' Two class predictions
#'
#' @details These data are a test set form a model built for two
#'  classes ("Class1" and "Class2"). There are columns for the true
#'  and predicted classes and column for the probabilities for each
#'  class.
#'
#' @name two_class_example
#' @aliases two_class_example
#' @docType data
#' @return \item{two_class_example}{a data frame}
#'
#' @keywords datasets
#' @examples
#' data(two_class_example)
#' str(two_class_example)
NULL

#' Cell body segmentation
#'
#' Hill, LaPan, Li and Haney (2007) develop models to predict which cells in a
#' high content screen were well segmented.  The data consists of 119 imaging
#' measurements on 2019. The original analysis used 1009 for training and 1010
#' as a test set (see the column called \code{case}).
#'
#' The outcome class is contained in a factor variable called \code{class} with
#' levels "PS" for poorly segmented and "WS" for well segmented.
#'
#' The raw data used in the paper can be found at the Biomedcentral website.
#' The version
#' contained in \code{cells} is modified. First, several discrete
#' versions of some of the predictors (with the suffix "Status") were removed.
#' Second, there are several skewed predictors with minimum values of zero
#' (that would benefit from some transformation, such as the log). A constant
#' value of 1 was added to these fields: \code{avg_inten_ch_2},
#' \code{fiber_align_2_ch_3}, \code{fiber_align_2_ch_4}, \code{spot_fiber_count_ch_4} and
#' \code{total_inten_ch_2}.
#'
#' @name cells
#' @docType data
#' @return \item{cells}{a tibble}
#' @source Hill, LaPan, Li and Haney (2007). Impact of image segmentation on
#' high-content screening data quality for SK-BR-3 cells, \emph{BMC
#' Bioinformatics}, Vol. 8, pg. 340,
#' \url{https://bmcbioinformatics.biomedcentral.com/articles/10.1186/1471-2105-8-340}.
#' @keywords datasets
#' @examples
#' data(cells)
#' str(cells)
NULL

#' Sacramento CA home prices
#'
#' This data frame contains house and sale price data for 932 homes in
#' Sacramento CA.  The original data were obtained from the website for the
#' SpatialKey software. From their website: "The Sacramento real estate
#' transactions file is a list of 985 real estate transactions in the
#' Sacramento area reported over a five-day period, as reported by the
#' Sacramento Bee." Google was used to fill in missing/incorrect data.
#'
#'
#' @name Sacramento
#' @docType data
#' @return \item{Sacramento}{a tibble}
#' @source SpatialKey website:
#' \url{https://support.spatialkey.com/spatialkey-sample-csv-data/}
#' @keywords datasets
#' @examples
#' data(Sacramento)
#' str(Sacramento)
NULL

#' Credit data
#'
#' These data are from the website of Dr. Lluís A. Belanche Muñoz by way of a
#' github repository of Dr. Gaston Sanchez. One data point is a missing outcome
#' was removed from the original data.
#'
#' @name credit_data
#' @aliases credit_data
#' @docType data
#' @return \item{credit_data}{a data frame}
#'
#' @source https://github.com/gastonstat/CreditScoring,
#' http://bit.ly/2kkBFrk
#'
#' @keywords datasets
#' @examples
#' data(credit_data)
#' str(credit_data)
NULL

#' Chicago ridership data
#'
#' @details These data are from Kuhn and Johnson (2020) and contain an
#'  _abbreviated_ training set for modeling the number of people (in thousands)
#'  who enter the Clark and Lake L station.
#'
#' The `date` column corresponds to the current date. The columns with station
#'  names (`Austin` through `California`) are a _sample_ of the columns used in
#'  the original analysis (for file size reasons). These are 14 day lag
#'  variables (i.e. `date - 14 days`). There are columns related to weather and
#'  sports team schedules.
#'
#' The station at 35th and Archer is contained in the column `Archer_35th` to
#' make it a valid R column name.
#'
#'
#' @name Chicago
#' @aliases Chicago stations
#' @docType data
#' @return \item{Chicago}{a tibble} \item{stations}{a vector of station names}
#'
#' @source Kuhn and Johnson (2020), _Feature Engineering and Selection_,
#' Chapman and Hall/CRC . \url{https://bookdown.org/max/FES/} and
#' \url{https://github.com/topepo/FES}
#'
#'
#' @keywords datasets
#' @examples
#' data(Chicago)
#' str(Chicago)
#' stations
NULL

#' Leaf identification data (Flavia)
#'
#' @description
#' Image analysis of leaves to predict species.
#'
#' @name leaf_id_flavia
#' @aliases leaf_id_flavia
#' @docType data
#' @return \item{leaf_id_flavia}{a data frame}
#'
#' @details
#' From the original manuscript: "The Flavia dataset contains 1907 leaf images.
#' There are 32 different species and each has 50-77 images. Scanners and
#' digital cameras are used to acquire the leaf images on a plain background.
#' The isolated leaf images contain blades only, without a petiole. These leaf
#' images are collected from the most common plants in Yangtze, Delta,
#' China. Those leaves were sampled on the campus of the Nanjing University and
#' the Sun Yat-Sen arboretum, Nanking, China."
#'
#' The reference below has details information on the features used for
#' prediction.
#'
#' Columns:
#' \itemize{
#'  \item \code{species}:  factor (32 levels)
#'  \item \code{apex}:  factor (9 levels)
#'  \item \code{base}:  factor (6 levels)
#'  \item \code{shape}:  factor (5 levels)
#'  \item \code{denate_edge}:  factor (levels: 'no' and 'yes')
#'  \item \code{lobed_edge}:  factor (levels: 'no' and 'yes')
#'  \item \code{smooth_edge}:  factor (levels: 'no' and 'yes')
#'  \item \code{toothed_edge}:  factor (levels: 'no' and 'yes')
#'  \item \code{undulate_edge}:  factor (levels: 'no' and 'yes')
#'  \item \code{outlying_polar}:  numeric
#'  \item \code{skewed_polar}:  numeric
#'  \item \code{clumpy_polar}:  numeric
#'  \item \code{sparse_polar}:  numeric
#'  \item \code{striated_polar}:  numeric
#'  \item \code{convex_polar}:  numeric
#'  \item \code{skinny_polar}:  numeric
#'  \item \code{stringy_polar}:  numeric
#'  \item \code{monotonic_polar}:  numeric
#'  \item \code{outlying_contour}:  numeric
#'  \item \code{skewed_contour}:  numeric
#'  \item \code{clumpy_contour}:  numeric
#'  \item \code{sparse_contour}:  numeric
#'  \item \code{striated_contour}:  numeric
#'  \item \code{convex_contour}:  numeric
#'  \item \code{skinny_contour}:  numeric
#'  \item \code{stringy_contour}:  numeric
#'  \item \code{monotonic_contour}:  numeric
#'  \item \code{num_max_points}:  numeric
#'  \item \code{num_min_points}:  numeric
#'  \item \code{diameter}:  numeric
#'  \item \code{area}:  numeric
#'  \item \code{perimeter}:  numeric
#'  \item \code{physiological_length}:  numeric
#'  \item \code{physiological_width}:  numeric
#'  \item \code{aspect_ratio}:  numeric
#'  \item \code{rectangularity}:  numeric
#'  \item \code{circularity}:  numeric
#'  \item \code{compactness}:  numeric
#'  \item \code{narrow_factor}:  numeric
#'  \item \code{perimeter_ratio_diameter}:  numeric
#'  \item \code{perimeter_ratio_length}:  numeric
#'  \item \code{perimeter_ratio_lw}:  numeric
#'  \item \code{num_convex_points}:  numeric
#'  \item \code{perimeter_convexity}:  numeric
#'  \item \code{area_convexity}:  numeric
#'  \item \code{area_ratio_convexity}:  numeric
#'  \item \code{equivalent_diameter}:  numeric
#'  \item \code{eccentricity}:  numeric
#'  \item \code{contrast}:  numeric
#'  \item \code{correlation_texture}:  numeric
#'  \item \code{inverse_difference_moments}:  numeric
#'  \item \code{entropy}:  numeric
#'  \item \code{mean_red_val}:  numeric
#'  \item \code{mean_green_val}:  numeric
#'  \item \code{mean_blue_val}:  numeric
#'  \item \code{std_red_val}:  numeric
#'  \item \code{std_green_val}:  numeric
#'  \item \code{std_blue_val}:  numeric
#'  \item \code{correlation}:  numeric
#' }
#' @source
#' Lakshika, Jayani PG, and Thiyanga S. Talagala. "Computer-aided interpretable
#' features for leaf image classification." _arXiv preprint_ arXiv:2106.08077
#' (2021).
#'
#' \url{https://github.com/SMART-Research/leaffeatures_paper}
#'
#' @examples
#' data(leaf_id_flavia)
#' str(leaf_id_flavia)
#'
NULL

#' Execution time data
#'
#' These data were collected from the CRAN web page for 13,626 R
#' packages. The time to complete the standard package checking
#' routine was collected In some cases, the package checking
#' process is stopped due to errors and these data are treated as
#' censored. It is less than 1 percent.
#'
#' As predictors, the associated package source code were
#' downloaded and parsed to create predictors, including
#'
#' * `authors`: The number of authors in the author field.
#' * `imports`: The number of imported packages.
#' * `suggests`: The number of packages suggested.
#' * `depends`: The number of hard dependencies.
#' * `Roxygen`: a binary indicator for whether Roxygen was used
#'   for documentation.
#' * `gh`: a binary indicator for whether the URL field contained
#'   a GitHub link.
#' * `rforge`: a binary indicator for whether the URL field
#'   contained a link to R-forge.
#' * `descr`: The number of characters (or, in some cases, bytes)
#'   in the description field.
#' * `r_count`: The number of R files in the R directory.
#' * `r_size`: The total disk size of the R files.
#' * `ns_import`: Estimated number of imported functions or methods.
#' * `ns_export`: Estimated number of exported functions or methods.
#' * `s3_methods`: Estimated number of S3 methods.
#' * `s4_methods`: Estimated number of S4 methods.
#' * `doc_count`: How many Rmd or Rnw files in the vignettes
#'   directory.
#' * `doc_size`: The disk size of the Rmd or Rnw files.
#' * `src_count`: The number of files in the `src` directory.
#' * `src_size`: The size on disk of files in the `src` directory.
#' * `data_count`  The number of files in the `data` directory.
#' * `data_size`: The size on disk of files in the `data` directory.
#' * `testthat_count`: The number of files in the `testthat`
#'   directory.
#' * `testthat_size`: The size on disk of files in the `testthat`
#'   directory.
#' * `check_time`: The time (in seconds) to run `R CMD check`
#'   using the "r-devel-windows-ix86+x86_64` flavor.
#' * `status`: An indicator for whether the tests completed.
#'
#' Data were collected on 2019-01-20.
#' @name check_times
#' @aliases check_times
#' @docType data
#' @return \item{check_times}{a data frame}
#'
#' @source CRAN
#'
#' @keywords datasets
#' @examples
#' data(check_times)
#' str(check_times)
NULL

#' Parabolic class boundary data
#'
#' @details These data were simulated. There are two correlated predictors and
#' two classes in the factor outcome.
#'
#' @name parabolic
#' @aliases parabolic
#' @docType data
#' @return \item{parabolic}{a data frame}
#'
#' @keywords datasets
#' @examples
#' data(parabolic)
#' str(parabolic)
NULL

#' Predicting steroidogenic toxicity with assay data
#'
#' @description
#' A set of _in vitro_ assays are used to quantify the risk of reproductive
#' toxicity via the disruption of steroidogenic pathways.
#'
#' @name steroidogenic_toxicity
#' @aliases steroidogenic_toxicity
#' @docType data
#' @return A tibble with columns
#'  - `class`: factor(levels: toxic and nontoxic)
#'  - `cyp_11a1`: numeric
#'  - `cyp_11b1`: numeric
#'  - `cyp_11b2`: numeric
#'  - `cyp_17a1`: numeric
#'  - `cyp_19a1`: numeric
#'  - `cyp_21a1`: numeric
#'  - `hsd3b2`: numeric
#'  - `star`: numeric
#'  - `progesterone`: numeric
#'  - `testosterone`: numeric
#'  - `dhea`: numeric
#'  - `cortisol`: numeric

#' @details
#' H295R cells were used to measure the effect with two sets of assay results.
#' The first includes a set of protein measurements on: cytochrome P450 enzymes
#' ("cyp"s), STAR, and 3BHSD2. The second include hormone measurements for
#' DHEA, progesterone, testosterone, and cortisol.
#'
#' Columns:
#' \itemize{
#'  \item \code{class}: factor (levels: 'toxic' and 'nontoxic')
#'  \item \code{cyp_11a1}: numeric
#'  \item \code{cyp_11b1}: numeric
#'  \item \code{cyp_11b2}: numeric
#'  \item \code{cyp_17a1}: numeric
#'  \item \code{cyp_19a1}: numeric
#'  \item \code{cyp_21a1}: numeric
#'  \item \code{hsd3b2}: numeric
#'  \item \code{star}: numeric
#'  \item \code{progesterone}: numeric
#'  \item \code{testosterone}: numeric
#'  \item \code{dhea}: numeric
#'  \item \code{cortisol}: numeric
#' }
#'
#' @source
#' Maglich, J. M., Kuhn, M., Chapin, R. E., & Pletcher, M. T. (2014). More than
#' just hormones: H295R cells as predictors of reproductive toxicity.
#' _Reproductive Toxicology_, 45, 77-86.
#'
#' @examples
#' data(steroidogenic_toxicity)
#' str(steroidogenic_toxicity)
#'
NULL

#' Kelly Blue Book resale data for 2005 model year GM cars
#'
#' Kuiper (2008) collected data on Kelly Blue Book resale data for 804 GM cars (2005 model year).
#'
#' @name car_prices
#' @docType data
#' @return \item{car_prices}{data frame of the suggested retail price (column \code{Price}) and various
#' characteristics of each car (columns \code{Mileage}, \code{Cylinder}, \code{Doors}, \code{Cruise},
#' \code{Sound}, \code{Leather}, \code{Buick}, \code{Cadillac}, \code{Chevy}, \code{Pontiac}, \code{Saab},
#'  \code{Saturn}, \code{convertible}, \code{coupe}, \code{hatchback}, \code{sedan} and \code{wagon})}
#' @source Kuiper, S. (2008). Introduction to Multiple Regression: How Much Is Your Car Worth?,
#' \emph{Journal of Statistics Education}, Vol. 16
#' \url{https://jse.amstat.org/jse_archive.htm#2008}.
#' @keywords datasets
#' @examples
#' data(car_prices)
#' str(car_prices)
NULL

#' Food Delivery Time Data
#'
#' @details
#' These data are from a study of food delivery times in minutes (i.e., the time from the
#' initial order to receiving the food) for a single restaurant. The data
#' contains 10,012 orders from a specific restaurant. The predictors include:
#' \itemize{
#' \item The time, in decimal hours, of the order.
#' \item The day of the week for the order.
#' \item The approximate distance in miles between the restaurant and the delivery
#'       location.
#' \item A set of 27 predictors that count the number of distinct menu items
#'       in the order.
#' }
#'
#' No times are censored.
#'
#' @name deliveries
#' @aliases deliveries
#' @docType data
#' @return \item{deliveries}{a tibble}
#'
#' @keywords datasets
#' @examples
#' data(deliveries)
#' str(deliveries)
NULL

#' Fine foods example data
#'
#' @details
#' These data are from Amazon, who describe it as "This dataset consists of
#'  reviews of fine foods from amazon. The data span a period of more than 10
#'  years, including all ~500,000 reviews up to October 2012. Reviews include
#'  product and user information, ratings, and a plaintext review."
#'
#' A subset of the data are contained here and are split into a training and
#'  test set. The training set sampled 10 products and retained all of their
#'  individual reviews. Since the reviews within these products are correlated,
#'  we recommend resampling the data using a leave-one-product-out approach. The
#'  test set sampled 500 products that were not included in the training set
#'  and selected a single review at random for each.
#'
#' There is a column for the product, a column for the text of the review, and
#'  a factor column for a class variable. The outcome is whether the reviewer
#'  gave the product a 5-star rating or not.
#'
#' @name small_fine_foods
#' @aliases small_fine_foods training_data testing_data
#' @docType data
#' @return \item{training_data,testing_data}{tibbles}
#'
#' @source https://snap.stanford.edu/data/web-FineFoods.html
#'
#'
#' @keywords datasets
#' @examples
#' data(small_fine_foods)
#' str(training_data)
#' str(testing_data)
NULL

#' Sample time series data
#'
#' @details Drink sales. The exact name of the series from FRED is:
#' "Merchant Wholesalers, Except Manufacturers' Sales Branches and Offices
#' Sales: Nondurable Goods: Beer, Wine, and Distilled Alcoholic Beverages Sales"
#'
#' @name drinks
#' @aliases drinks
#' @docType data
#' @return \item{drinks}{a tibble}
#'
#' @source The Federal Reserve Bank of St. Louis website https://fred.stlouisfed.org/series/S4248SM144NCEN
#'
#' @keywords datasets
#' @examples
#' data(drinks)
#' str(drinks)
NULL

#' Chemical manufacturing process data set
#'
#' @description
#' A data set that models yield as a function of biological material predictors
#' and chemical structure predictors.
#'
#' @name chem_proc_yield
#' @aliases chem_proc_yield
#' @docType data
#' @return \item{chem_proc_yield}{a tibble}
#'
#' @details
#' This data set contains information about a chemical manufacturing
#' process, in which the goal is to understand the relationship between
#' the process and the resulting final product yield.  Raw material in
#' this process is put through a sequence of 27 steps to generate the
#' final pharmaceutical product.  The starting material is generated from
#' a biological unit and has a range of quality and characteristics.  The
#' objective in this project was to develop a model to predict percent
#' yield of the manufacturing process.  The data set consisted of 177
#' samples of biological material for which 57 characteristics were
#' measured.  Of the 57 characteristics, there were 12 measurements of
#' the biological starting material, and 45 measurements of the
#' manufacturing process.  The process variables included measurements
#' such as temperature, drying time, washing time, and concentrations of
#' by-products at various steps.  Some of the process measurements can
#' be controlled, while others are observed.  Predictors are continuous,
#' count, categorical; some are correlated, and some contain missing
#' values.  Samples are not independent because sets of samples come from
#' the same batch of biological starting material.
#'
#' Columns:
#' \itemize{
#'  \item \code{yield}:  numeric
#'  \item \code{bio_material_01} - \code{bio_material_12}:  numeric
#'  \item \code{man_proc_01} - \code{man_proc_45}:  numeric
#' }
#' @source
#' Kuhn, Max, and Kjell Johnson. _Applied predictive modeling_. New York:
#' Springer, 2013.
#'
#' @examples
#' data(chem_proc_yield)
#' str(chem_proc_yield)
#'
NULL

#' Grant acceptance data
#'
#' A data set related to the success or failure of academic grants.
#'
#' The data are discussed in Kuhn and Johnson (2013):
#'
#' "These data are from a 2011 Kaggle competition sponsored by the University
#'  of Melbourne where there was interest in predicting whether or not a grant
#'  application would be accepted. Since public funding of grants had decreased
#'  over time, triaging grant applications based on their likelihood of success
#'  could be important for estimating the amount of potential funding to the
#'  university. In addition to predicting grant success, the university sought
#'  to understand factors that were important in predicting success."
#'
#'  The data ranged from 2005 and 2008 and the data spending strategy was
#'  driven by the date of the grant. Kuhn and Johnson (2013) describe:
#'
#' "The compromise taken here is to build models on the pre-2008 data and
#'  tune them by evaluating a random sample of 2,075 grants from 2008. Once the
#'  optimal parameters are determined, final model is built using these
#'  parameters and the entire training set (i.e., the data prior to 2008 and the
#'  additional 2,075 grants). A small holdout set of 518 grants from 2008 will
#'  be used to ensure that no gross methodology errors occur from repeatedly
#'  evaluating the 2008 data during model tuning. In the text, this set of
#'  samples is called the 2 0 0 8 holdout set. This small set of year 2008
#'  grants will be referred to as the test set and will not be evaluated until
#'  set of candidate models are identified."
#'
#' To emulate this, `grants_other` contains the training (pre-2008, n = 6,633)
#'  and holdout/validation data (2008, n = 1,557). `grants_test` has 518 grant
#'  samples from 2008. The object `grants_2008` is an integer vector that can
#'  be used to separate the modeling with the holdout/validation sets.
#'
#'
#' @name grants
#' @aliases grants_other grants_test grants_2008
#' @docType data
#' @return \item{grants_other,grants_test,grants_2008}{two tibbles and an integer
#' vector of data points used for training}
#' @source Kuhn and Johnson (2013). _Applied Predictive Modeling_. Springer.
#' @keywords datasets
#' @examples
#' data(grants)
#' str(grants_other)
#' str(grants_test)
#' str(grants_2008)
NULL

#' Raw cover type data
#'
#' These data are raw data describing different types of forest cover-types
#'   from the UCI Machine Learning Database (see link below). There is one
#'   column in the data that has a few difference pieces of textual
#'   information (of variable lengths).
#'
#' @name covers
#' @aliases covers
#' @docType data
#' @return \item{covers}{a data frame}
#'
#' @source https://archive.ics.uci.edu/ml/machine-learning-databases/covtype/covtype.info
#'
#' @keywords datasets
#' @examples
#' data(covers)
#' str(covers)
NULL

For these data, the training materials typically use: 

```r
library(tidymodels)

set.seed(4595)
data_split <- initial_split(ames, strata = "Sale_Price")
ames_train <- training(data_split)
ames_test  <- testing(data_split)

set.seed(2453)
ames_folds<- vfold_cv(ames_train)
```

# classification simulation

    Code
      sim_classification(5, method = "potato")
    Condition
      Error in `sim_classification()`:
      ! `method` must be one of "caret", not "potato".

---

    Code
      sim_classification(500, num_linear = -1)
    Condition
      Error in `sim_classification()`:
      ! `num_linear` must be a whole number larger than or equal to 0, not the number -1.

---

    Code
      sim_classification(-1)
    Condition
      Error in `sim_classification()`:
      ! `num_samples` must be a whole number larger than or equal to 1, not the number -1.

---

    Code
      sim_classification(1, intercept = NA)
    Condition
      Error in `sim_classification()`:
      ! `intercept` must be a number, not `NA`.

---

    Code
      sim_classification(1, keep_truth = NA)
    Condition
      Error in `sim_classification()`:
      ! `keep_truth` should be a single logical value, not `NA`.

---

    Code
      sim_classification(5, method = "potato")
    Condition
      Error in `sim_classification()`:
      ! `method` must be one of "caret", not "potato".

# sapp_2014_1 simulation

    Code
      sim_regression(5, method = "potato")
    Condition
      Error in `sim_regression()`:
      ! `method` must be one of "sapp_2014_1", "sapp_2014_2", "van_der_laan_2007_1", "van_der_laan_2007_2", "hooker_2004", or "worley_1987", not "potato".

# noise simulation

    Code
      sim_noise(5, cov_type = "potato")
    Condition
      Error in `sim_noise()`:
      ! `cov_type` must be one of "exchangeable" or "toeplitz", not "potato".

---

    Code
      sim_noise(5, outcome = "potato")
    Condition
      Error in `sim_noise()`:
      ! `outcome` must be one of "none", "classification", or "regression", not "potato".

---

    Code
      sim_noise(num_vars, num_linear = -1)
    Condition
      Error in `sim_noise()`:
      ! unused argument (num_linear = -1)

---

    Code
      sim_noise(-1)
    Condition
      Error in `sim_noise()`:
      ! `num_samples` must be a whole number larger than or equal to 1, not the number -1.

---

    Code
      sim_noise(1, num_classes = 1)
    Condition
      Error in `sim_noise()`:
      ! `num_vars` must be a whole number, not absent.

---

    Code
      sim_noise(1, cov_param = NA)
    Condition
      Error in `sim_noise()`:
      ! `num_vars` must be a whole number, not absent.

# logistic simulation

    Code
      sim_logistic(10, ~A, correlation = NA)
    Condition
      Error in `sim_logistic()`:
      ! `correlation` must be a number, not `NA`.

---

    Code
      sim_logistic(-1)
    Condition
      Error in `sim_logistic()`:
      ! `num_samples` must be a whole number larger than or equal to 1, not the number -1.

---

    Code
      sim_logistic(10, ~A, keep_truth = 1)
    Condition
      Error in `sim_logistic()`:
      ! `keep_truth` should be a single logical value, not the number 1.

# multinomial simulation

    i In index: 1.
    Caused by error in `.f()`:
    ! The model equations should only use variables/objects `A` and `B`.

---

    Code
      sim_multinomial(10, ~A, correlation = NA)
    Condition
      Error in `sim_multinomial()`:
      ! `correlation` must be a number, not `NA`.

---

    Code
      sim_multinomial(-1)
    Condition
      Error in `sim_multinomial()`:
      ! `num_samples` must be a whole number larger than or equal to 1, not the number -1.

---

    Code
      sim_multinomial(10, ~A, keep_truth = 1)
    Condition
      Error in `sim_multinomial()`:
      ! `keep_truth` should be a single logical value, not the number 1.

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Smithsonian.R
\docType{data}
\name{Smithsonian}
\alias{Smithsonian}
\title{Smithsonian museums}
\source{
https://en.wikipedia.org/wiki/List_of_Smithsonian_museums
}
\value{
\item{Smithsonian}{a tibble}
}
\description{
Geocodes for the Smithsonian museums (circa 2018).
}
\examples{
data(Smithsonian)
str(Smithsonian)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cat_adoption.R
\docType{data}
\name{cat_adoption}
\alias{cat_adoption}
\title{Cat Adoption}
\source{
\url{https://data.longbeach.gov/explore/dataset/animal-shelter-intakes-and-outcomes/information/}
on 2024-06-17
}
\value{
tibble
}
\description{
A subset of the cats at the animal shelter in Long Beach, California, USA.
}
\details{
A data frame with 2257 rows and 19 columns:
\describe{
\item{time}{The time the cat spent at the shelter.}
\item{event}{The event of interest is the cat being homed or returned to
its original location (i.e., owner or community). The non-event is the cat
being transferred to another shelter or dying. Zero indicates a non-event
(censored), and one corresponds to the event occurring.}
\item{sex}{The sex of the cat.}
\item{neutered}{Whether the cat is neutered.}
\item{intake_condition}{The intake condition of the cat.}
\item{intake_type}{The type of intake.}
\item{latitude}{Latitude of the intersection/cross street of intake or capture.}
\item{longitude}{Longitude of the intersection/cross street of intake or capture.}
\item{black,brown,brown_tabby,calico,cream,gray,gray_tabby,orange,orange_tabby,tan,tortie,white}{Indicators for the color/pattern of the cat's fur.}
}
}
\examples{
str(cat_adoption)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/penguins.R
\docType{data}
\name{penguins}
\alias{penguins}
\title{Palmer Station penguin data}
\source{
Gorman KB, Williams TD, Fraser WR (2014) Ecological Sexual Dimorphism
and Environmental Variability within a Community of Antarctic Penguins
(\emph{Genus Pygoscelis}). PLoS ONE 9(3): e90081.
\doi{10.1371/journal.pone.0090081}

\url{https://github.com/allisonhorst/palmerpenguins}
}
\value{
\item{penguins}{a tibble}
}
\description{
A data set from Gorman, Williams, and Fraser (2014) containing measurements
from different types of penguins. This version of the data was retrieved from
Allison Horst's \code{palmerpenguins} package on 2020-06-22.
}
\examples{
data(penguins)
str(penguins)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/credit_data.R
\docType{data}
\name{credit_data}
\alias{credit_data}
\title{Credit data}
\source{
https://github.com/gastonstat/CreditScoring,
http://bit.ly/2kkBFrk
}
\value{
\item{credit_data}{a data frame}
}
\description{
These data are from the website of Dr. Lluís A. Belanche Muñoz by way of a
github repository of Dr. Gaston Sanchez. One data point is a missing outcome
was removed from the original data.
}
\examples{
data(credit_data)
str(credit_data)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/grants.R
\docType{data}
\name{grants}
\alias{grants}
\alias{grants_other}
\alias{grants_test}
\alias{grants_2008}
\title{Grant acceptance data}
\source{
Kuhn and Johnson (2013). \emph{Applied Predictive Modeling}. Springer.
}
\value{
\item{grants_other,grants_test,grants_2008}{two tibbles and an integer
vector of data points used for training}
}
\description{
A data set related to the success or failure of academic grants.
}
\details{
The data are discussed in Kuhn and Johnson (2013):

"These data are from a 2011 Kaggle competition sponsored by the University
of Melbourne where there was interest in predicting whether or not a grant
application would be accepted. Since public funding of grants had decreased
over time, triaging grant applications based on their likelihood of success
could be important for estimating the amount of potential funding to the
university. In addition to predicting grant success, the university sought
to understand factors that were important in predicting success."

The data ranged from 2005 and 2008 and the data spending strategy was
driven by the date of the grant. Kuhn and Johnson (2013) describe:

"The compromise taken here is to build models on the pre-2008 data and
tune them by evaluating a random sample of 2,075 grants from 2008. Once the
optimal parameters are determined, final model is built using these
parameters and the entire training set (i.e., the data prior to 2008 and the
additional 2,075 grants). A small holdout set of 518 grants from 2008 will
be used to ensure that no gross methodology errors occur from repeatedly
evaluating the 2008 data during model tuning. In the text, this set of
samples is called the 2 0 0 8 holdout set. This small set of year 2008
grants will be referred to as the test set and will not be evaluated until
set of candidate models are identified."

To emulate this, \code{grants_other} contains the training (pre-2008, n = 6,633)
and holdout/validation data (2008, n = 1,557). \code{grants_test} has 518 grant
samples from 2008. The object \code{grants_2008} is an integer vector that can
be used to separate the modeling with the holdout/validation sets.
}
\examples{
data(grants)
str(grants_other)
str(grants_test)
str(grants_2008)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/solubility.R
\docType{data}
\name{solubility_test}
\alias{solubility_test}
\title{Solubility predictions from MARS model}
\source{
Kuhn, M., Johnson, K. (2013) \emph{Applied Predictive
Modeling}, Springer
}
\value{
\item{solubility_test}{a data frame}
}
\description{
Solubility predictions from MARS model
}
\details{
For the solubility data in Kuhn and Johnson (2013),
these data are the test set results for the MARS model. The
observed solubility (in column \code{solubility}) and the model
results (\code{prediction}) are contained in the data.
}
\examples{
data(solubility_test)
str(solubility_test)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pathology.R
\docType{data}
\name{pathology}
\alias{pathology}
\title{Liver pathology data}
\source{
Altman, D.G., Bland, J.M. (1994) ``Diagnostic tests 1:
sensitivity and specificity,'' \emph{British Medical Journal},
vol 308, 1552.
}
\value{
\item{pathology}{a data frame}
}
\description{
Liver pathology data
}
\details{
These data have the results of a \emph{x}-ray examination
to determine whether liver is abnormal or not (in the \code{scan}
column) versus the more extensive pathology results that
approximate the truth (in \code{pathology}).
}
\examples{
data(pathology)
str(pathology)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/crickets.R
\docType{data}
\name{crickets}
\alias{crickets}
\title{Rates of Cricket Chirps}
\source{
Mangiafico, S. 2015. "An R Companion for the Handbook of Biological
Statistics." \url{https://rcompanion.org/handbook/}.

McDonald, J. 2009. \emph{Handbook of Biological Statistics}. Sparky House Publishing.
}
\value{
\item{crickets}{a tibble}
}
\description{
These data are from from McDonald (2009), by way of Mangiafico (2015), on
the relationship between the ambient temperature and the rate of cricket
chirps per minute. Data were collected for two species of the genus \emph{Oecanthus}: \emph{O. exclamationis}
and \emph{O. niveus}. The data are contained in a data frame called \code{crickets} with
a total of 31 data points.
}
\examples{
data(crickets)
str(crickets)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tate_text.R
\docType{data}
\name{tate_text}
\alias{tate_text}
\title{Tate Gallery modern artwork metadata}
\source{
\itemize{
\item \url{https://github.com/tategallery/collection}
\item \url{https://www.tate.org.uk/}
}
}
\value{
\item{tate_text}{a tibble}
}
\description{
Metadata such as artist, title, and year created for recent artworks owned
by the Tate Gallery. Only artworks created during or after 1990 are
included, and the metadata source was last updated in 2014. The Tate Gallery
provides these data but requests users to be respectful of their
\href{https://github.com/tategallery/collection#usage-guidelines-for-open-data}{guidelines for use}.
}
\examples{
data(tate_text)
str(tate_text)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sacremento.R
\docType{data}
\name{Sacramento}
\alias{Sacramento}
\title{Sacramento CA home prices}
\source{
SpatialKey website:
\url{https://support.spatialkey.com/spatialkey-sample-csv-data/}
}
\value{
\item{Sacramento}{a tibble}
}
\description{
This data frame contains house and sale price data for 932 homes in
Sacramento CA.  The original data were obtained from the website for the
SpatialKey software. From their website: "The Sacramento real estate
transactions file is a list of 985 real estate transactions in the
Sacramento area reported over a five-day period, as reported by the
Sacramento Bee." Google was used to fill in missing/incorrect data.
}
\examples{
data(Sacramento)
str(Sacramento)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/covers.R
\docType{data}
\name{covers}
\alias{covers}
\title{Raw cover type data}
\source{
https://archive.ics.uci.edu/ml/machine-learning-databases/covtype/covtype.info
}
\value{
\item{covers}{a data frame}
}
\description{
These data are raw data describing different types of forest cover-types
from the UCI Machine Learning Database (see link below). There is one
column in the data that has a few difference pieces of textual
information (of variable lengths).
}
\examples{
data(covers)
str(covers)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ames.R
\docType{data}
\name{ames}
\alias{ames}
\title{Ames Housing Data}
\source{
De Cock, D. (2011). "Ames, Iowa: Alternative to the Boston Housing Data as an End of Semester Regression Project," \emph{Journal of Statistics Education},  Volume 19, Number 3.

\url{https://jse.amstat.org/v19n3/decock/DataDocumentation.txt}

\url{https://jse.amstat.org/v19n3/decock.pdf}
}
\value{
\item{ames}{a tibble}
}
\description{
A data set from De Cock (2011) has 82 fields were recorded for 2,930
properties in Ames IA. This version is copies from the \code{AmesHousing} package
but does not include a few quality columns that appear to be outcomes
rather than predictors.
}
\details{
See this links for the sources below for more information as well as
\code{?AmesHousing::make_ames}.

For these data, the training materials typically use:

\if{html}{\out{<div class="sourceCode r">}}\preformatted{library(tidymodels)

set.seed(4595)
data_split <- initial_split(ames, strata = "Sale_Price")
ames_train <- training(data_split)
ames_test  <- testing(data_split)

set.seed(2453)
ames_folds<- vfold_cv(ames_train)
}\if{html}{\out{</div>}}
}
\examples{
data(ames)
str(ames)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/drinks.R
\docType{data}
\name{drinks}
\alias{drinks}
\title{Sample time series data}
\source{
The Federal Reserve Bank of St. Louis website https://fred.stlouisfed.org/series/S4248SM144NCEN
}
\value{
\item{drinks}{a tibble}
}
\description{
Sample time series data
}
\details{
Drink sales. The exact name of the series from FRED is:
"Merchant Wholesalers, Except Manufacturers' Sales Branches and Offices
Sales: Nondurable Goods: Beer, Wine, and Distilled Alcoholic Beverages Sales"
}
\examples{
data(drinks)
str(drinks)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hpc_cv.R
\docType{data}
\name{hpc_cv}
\alias{hpc_cv}
\title{Class probability predictions}
\source{
Kuhn, M., Johnson, K. (2013) \emph{Applied Predictive
Modeling}, Springer
}
\value{
\item{hpc_cv}{a data frame}
}
\description{
Class probability predictions
}
\details{
This data frame contains the predicted classes and
class probabilities for a linear discriminant analysis model fit
to the HPC data set from Kuhn and Johnson (2013). These data are
the assessment sets from a 10-fold cross-validation scheme. The
data column columns for the true class (\code{obs}), the class
prediction (\code{pred}) and columns for each class probability
(columns \code{VF}, \code{F}, \code{M}, and \code{L}). Additionally, a column for
the resample indicator is included.
}
\examples{
data(hpc_cv)
str(hpc_cv)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lending_club.R
\docType{data}
\name{lending_club}
\alias{lending_club}
\title{Loan data}
\source{
Lending Club Statistics https://www.lendingclub.com/info/download-data.action
}
\value{
\item{lending_club}{a data frame}
}
\description{
Loan data
}
\details{
These data were downloaded from the Lending Club
access site (see below) and are from the first quarter of 2016.
A subset of the rows and variables are included here. The
outcome is in the variable \code{Class} and is either "good" (meaning
that the loan was fully paid back or currently on-time) or "bad"
(charged off, defaulted, of 21-120 days late). A data dictionary
can be found on the source website.
}
\examples{
data(lending_club)
str(lending_club)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scat.R
\docType{data}
\name{scat}
\alias{scat}
\title{Morphometric data on scat}
\source{
Reid, R. E. B. (2015). A morphometric modeling approach to
distinguishing among bobcat, coyote and gray fox scats. \emph{Wildlife
Biology}, 21(5), 254-262
}
\value{
\item{scat}{a tibble}
}
\description{
Reid (2015) collected data on animal feses in coastal California. The data
consist of DNA verified species designations as well as fields related to
the time and place of the collection and the scat itself. The data are on
the three main species.
}
\examples{
data(scat)
str(scat)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wa_churn.R
\docType{data}
\name{wa_churn}
\alias{wa_churn}
\title{Watson churn data}
\source{
IBM Watson Analytics https://ibm.co/2sOvyvy
}
\value{
\item{wa_churn}{a data frame}
}
\description{
Watson churn data
}
\details{
These data were downloaded from the IBM Watson site
(see below) in September 2018. The data contain a factor for
whether a customer churned or not. Alternatively, the \code{tenure}
column presumably contains information on how long the customer
has had an account. A survival analysis can be done on this
column using the \code{churn} outcome as the censoring information. A
data dictionary can be found on the source website.
}
\examples{
data(wa_churn)
str(wa_churn)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/modeldata-package.R
\docType{package}
\name{modeldata-package}
\alias{modeldata}
\alias{modeldata-package}
\title{modeldata: Data Sets Useful for Modeling Examples}
\description{
Data sets used for demonstrating or testing model-related packages are contained in this package.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://modeldata.tidymodels.org}
  \item \url{https://github.com/tidymodels/modeldata}
  \item Report bugs at \url{https://github.com/tidymodels/modeldata/issues}
}

}
\author{
\strong{Maintainer}: Max Kuhn \email{max@posit.co}

Other contributors:
\itemize{
  \item Posit Software, PBC (03wc8by49) [copyright holder, funder]
}

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pd_speech.R
\docType{data}
\name{pd_speech}
\alias{pd_speech}
\title{Parkinson's disease speech classification data set}
\source{
UCI ML repository (data) https://archive.ics.uci.edu/ml/datasets/Parkinson\%27s+Disease+Classification#,

Sakar et al (2019), "A comparative analysis of speech signal processing
algorithms for Parkinson’s disease classification and the use of the tunable
Q-factor wavelet transform", \emph{Applied Soft Computing}, V74, pg 255-263.
}
\value{
\item{pd_speech}{a data frame}
}
\description{
Parkinson's disease speech classification data set
}
\details{
From the UCI ML archive, the description is "The data used in this
study were gathered from 188 patients with PD (107 men and 81 women) with
ages ranging from 33 to 87 (65.1 p/m 10.9) at the Department of Neurology
in Cerrahpaşa Faculty of Medicine, Istanbul University. The control group
consists of 64 healthy individuals (23 men and 41 women) with ages varying
between 41 and 82 (61.1 p/m 8.9). During the data collection process,
the microphone is set to 44.1 KHz and following the physician's examination,
the sustained phonation of the vowel \verb{/a/} was collected from each subject
with three repetitions."

The data here are averaged over the replicates.
}
\examples{
data(pd_speech)
str(pd_speech)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ischemic_stroke.R
\docType{data}
\name{ischemic_stroke}
\alias{ischemic_stroke}
\title{Clinical data used to predict ischemic stroke}
\source{
Kuhn, Max, and Kjell Johnson. \emph{Feature Engineering and Selection: A Practical
Approach for Predictive Models}. Chapman and Hall/CRC, 2019.
}
\value{
\item{ischemic_stroke}{a tibble}
}
\description{
A data set to predict a binary outcome using imaging and patient data.
}
\details{
These data were gathered to predict patient risk for ischemic stroke. A
historical set of patients with a range of carotid artery blockages were
selected. The data consisted of 126 patients, 44 of which had blockages
greater than 70\%. All patients had undergone Computed Tomography Angiography
(CTA) to generate a detailed three-dimensional visualization and
characterization of the blockage. These images were then analyzed in order to
compute several features related to the disease, including: percent stenosis,
arterial wall thickness, and tissue characteristics such as lipid-rich
necrotic core and calcification.

The group of patients in this study also had follow-up information on
whether or not a stroke occurred at a subsequent point in time. The data for
each patient also included commonly collected clinical characteristics for
risk of stroke such as whether or not the patient had atrial fibrillation,
coronary artery disease, and a history of smoking. Demographics of gender and
age were included as well. These readily available risk factors can be
thought of as another potentially useful predictor set that can be evaluated.
In fact, this set of predictors should be evaluated first to assess their
ability to predict stroke since these predictors are easy to collect, are
acquired at patient presentation, and do not require an expensive imaging
technique.

Columns:
\itemize{
\item \code{stroke}:  factor (levels: 'yes' and 'no')
\item \code{nascet_scale}:  numeric
\item \code{calc_vol}:  numeric
\item \code{calc_vol_prop}:  numeric
\item \code{matx_vol}:  numeric
\item \code{matx_vol_prop}:  numeric
\item \code{lrnc_vol}:  numeric
\item \code{lrnc_vol_prop}:  numeric
\item \code{max_calc_area}:  numeric
\item \code{max_calc_area_prop}:  numeric
\item \code{max_dilation_by_area}:  numeric
\item \code{max_matx_area}:  numeric
\item \code{max_matx_area_prop}:  numeric
\item \code{max_lrnc_area}:  numeric
\item \code{max_lrnc_area_prop}:  numeric
\item \code{max_max_wall_thickness}:  numeric
\item \code{max_remodeling_ratio}:  numeric
\item \code{max_stenosis_by_area}:  numeric
\item \code{max_wall_area}:  numeric
\item \code{wall_vol}:  numeric
\item \code{max_stenosis_by_diameter}:  numeric
\item \code{age}:  integer
\item \code{male}:  integer
\item \code{smoking_history}:  integer
\item \code{atrial_fibrillation}:  integer
\item \code{coronary_artery_disease}:  integer
\item \code{diabetes_history}:  integer
\item \code{hypercholesterolemia_history}:  integer
\item \code{hypertension_history}:  integer
}
}
\examples{
data(ischemic_stroke)
str(ischemic_stroke)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/okc.R
\docType{data}
\name{okc}
\alias{okc}
\title{OkCupid data}
\source{
Kim, A. Y., and A. Escobedo-Land. 2015. "OkCupid Data for
Introductory Statistics and Data Science Courses." \emph{Journal of
Statistics Education: An International Journal on the Teaching and
Learning of Statistics}.
}
\value{
\item{okc}{a data frame}
}
\description{
These are a sample of columns of users of OkCupid dating website. The data
are from Kim and Escobedo-Land (2015). Permission to use this data set was
explicitly granted by OkCupid.
}
\examples{
data(okc)
str(okc)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/deliveries.R
\docType{data}
\name{deliveries}
\alias{deliveries}
\title{Food Delivery Time Data}
\value{
\item{deliveries}{a tibble}
}
\description{
Food Delivery Time Data
}
\details{
These data are from a study of food delivery times in minutes (i.e., the time from the
initial order to receiving the food) for a single restaurant. The data
contains 10,012 orders from a specific restaurant. The predictors include:
\itemize{
\item The time, in decimal hours, of the order.
\item The day of the week for the order.
\item The approximate distance in miles between the restaurant and the delivery
location.
\item A set of 27 predictors that count the number of distinct menu items
in the order.
}

No times are censored.
}
\examples{
data(deliveries)
str(deliveries)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/taxi.R
\docType{data}
\name{taxi}
\alias{taxi}
\title{Chicago taxi data set}
\source{
\url{https://data.cityofchicago.org/Transportation/Taxi-Trips/wrvz-psew}
}
\value{
tibble
}
\description{
A data set containing information on a subset of taxi trips in the city
of Chicago in 2022.
}
\details{
The source data are originally described on the linked City of Chicago
data portal. The data exported here are a pre-processed subset motivated by
the modeling problem of predicting whether a rider will tip or not.

\describe{
\item{tip}{Whether the rider left a tip. A factor with levels
"yes" and "no".}
\item{distance}{The trip distance, in odometer miles.}
\item{company}{The taxi company, as a factor. Companies that occurred
few times were binned as "other".}
\item{local}{Whether the trip's starting and ending locations are in the
same community. See the source data for community area values.}
\item{dow}{The day of the week in which the trip began, as a
factor.}
\item{month}{The month in which the trip began, as a factor.}
\item{hour}{The hour of the day in which the trip began, as a
numeric.}
}
}
\examples{
\donttest{
taxi
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cells.R
\docType{data}
\name{cells}
\alias{cells}
\title{Cell body segmentation}
\source{
Hill, LaPan, Li and Haney (2007). Impact of image segmentation on
high-content screening data quality for SK-BR-3 cells, \emph{BMC
Bioinformatics}, Vol. 8, pg. 340,
\url{https://bmcbioinformatics.biomedcentral.com/articles/10.1186/1471-2105-8-340}.
}
\value{
\item{cells}{a tibble}
}
\description{
Hill, LaPan, Li and Haney (2007) develop models to predict which cells in a
high content screen were well segmented.  The data consists of 119 imaging
measurements on 2019. The original analysis used 1009 for training and 1010
as a test set (see the column called \code{case}).
}
\details{
The outcome class is contained in a factor variable called \code{class} with
levels "PS" for poorly segmented and "WS" for well segmented.

The raw data used in the paper can be found at the Biomedcentral website.
The version
contained in \code{cells} is modified. First, several discrete
versions of some of the predictors (with the suffix "Status") were removed.
Second, there are several skewed predictors with minimum values of zero
(that would benefit from some transformation, such as the log). A constant
value of 1 was added to these fields: \code{avg_inten_ch_2},
\code{fiber_align_2_ch_3}, \code{fiber_align_2_ch_4}, \code{spot_fiber_count_ch_4} and
\code{total_inten_ch_2}.
}
\examples{
data(cells)
str(cells)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hpc_data.R
\docType{data}
\name{hpc_data}
\alias{hpc_data}
\title{High-performance computing system data}
\source{
Kuhn, M., Johnson, K. (2013) \emph{Applied Predictive Modeling}, Springer.
}
\value{
\item{hpc_data}{a tibble}
}
\description{
Kuhn and Johnson (2013) describe a data set where characteristics of unix
jobs were used to classify there completion times as either very fast
(1 min or less, \code{VF}), fast (1–50 min, \code{F}), moderate (5–30 min, \code{M}), or
long (greater than 30 min, \code{L}).
}
\examples{

data(hpc_data)
str(hpc_data)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chem_proc_yield.R
\docType{data}
\name{chem_proc_yield}
\alias{chem_proc_yield}
\title{Chemical manufacturing process data set}
\source{
Kuhn, Max, and Kjell Johnson. \emph{Applied predictive modeling}. New York:
Springer, 2013.
}
\value{
\item{chem_proc_yield}{a tibble}
}
\description{
A data set that models yield as a function of biological material predictors
and chemical structure predictors.
}
\details{
This data set contains information about a chemical manufacturing
process, in which the goal is to understand the relationship between
the process and the resulting final product yield.  Raw material in
this process is put through a sequence of 27 steps to generate the
final pharmaceutical product.  The starting material is generated from
a biological unit and has a range of quality and characteristics.  The
objective in this project was to develop a model to predict percent
yield of the manufacturing process.  The data set consisted of 177
samples of biological material for which 57 characteristics were
measured.  Of the 57 characteristics, there were 12 measurements of
the biological starting material, and 45 measurements of the
manufacturing process.  The process variables included measurements
such as temperature, drying time, washing time, and concentrations of
by-products at various steps.  Some of the process measurements can
be controlled, while others are observed.  Predictors are continuous,
count, categorical; some are correlated, and some contain missing
values.  Samples are not independent because sets of samples come from
the same batch of biological starting material.

Columns:
\itemize{
\item \code{yield}:  numeric
\item \code{bio_material_01} - \code{bio_material_12}:  numeric
\item \code{man_proc_01} - \code{man_proc_45}:  numeric
}
}
\examples{
data(chem_proc_yield)
str(chem_proc_yield)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hepatic_injury_qsar.R
\docType{data}
\name{hepatic_injury_qsar}
\alias{hepatic_injury_qsar}
\title{Predicting hepatic injury from chemical information}
\source{
Kuhn, Max, and Kjell Johnson. \emph{Applied predictive modeling}. New York:
Springer, 2013.
}
\value{
\item{hepatic_injury_qsar}{a tibble}
}
\description{
A quantitative structure-activity relationship (QSAR) data set to predict
when a molecule has risk associated with liver function.
}
\details{
This  data set was used to develop a model for predicting compounds'
probability of causing hepatic injury (i.e. liver damage). This data set
consisted of 281 unique compounds; 376 predictors were measured or computed
for each. The response was categorical (either "none", "mild", or "severe"),
and was highly unbalanced.

This kind of response often occurs in pharmaceutical data because companies
steer away from creating molecules that have undesirable characteristics.
Therefore, well-behaved molecules often greatly outnumber undesirable
molecules. The predictors consisted of measurements from 184 biological
screens and 192 chemical feature predictors. The biological predictors
represent activity for each screen and take values between 0 and 10 with a
mode of 4. The chemical feature predictors represent counts of important
sub-structures as well as measures of physical properties that are thought to
be associated with hepatic injury.

Columns:
\itemize{
\item \code{class}:  ordered and factor (levels: 'none', 'mild', and 'severe')
\item \code{bio_assay_001} - \code{bio_assay_184}:  numeric
\item \code{chem_fp_001} - \code{chem_fp_192}:  numeric
}
}
\examples{
data(hepatic_injury_qsar)
str(hepatic_injury_qsar)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/two_class_dat.R
\docType{data}
\name{two_class_example}
\alias{two_class_example}
\title{Two class predictions}
\value{
\item{two_class_example}{a data frame}
}
\description{
Two class predictions
}
\details{
These data are a test set form a model built for two
classes ("Class1" and "Class2"). There are columns for the true
and predicted classes and column for the probabilities for each
class.
}
\examples{
data(two_class_example)
str(two_class_example)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/attrition.R
\docType{data}
\name{attrition}
\alias{attrition}
\title{Job attrition}
\source{
The IBM Watson Analytics Lab website https://www.ibm.com/communities/analytics/watson-analytics-blog/hr-employee-attrition/
}
\value{
\item{attrition}{a data frame}
}
\description{
Job attrition
}
\details{
These data are from the IBM Watson Analytics Lab.
The website describes the data with \dQuote{Uncover the
factors that lead to employee attrition and explore important
questions such as \sQuote{show me a breakdown of distance
from home by job role and attrition} or \sQuote{compare
average monthly income by education and attrition}. This is a
fictional data set created by IBM data scientists.}. There
are 1470 rows.
}
\examples{
data(attrition)
str(attrition)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hotel_rates.R
\docType{data}
\name{hotel_rates}
\alias{hotel_rates}
\title{Daily Hotel Rate Data}
\source{
\url{https://github.com/rfordatascience/tidytuesday/tree/master/data/2020/2020-02-11}
}
\description{
A data set to predict the average daily rate for a hotel in Lisbon Portugal.
}
\details{
Data are originally described in Antonio, de Almeida, and Nunes (2019).
This version of the data is filtered for one hotel (the "Resort Hotel") and
is intended as regression data set for predicting the average daily rate for
a room. The data are post-2016; the 2016 data were used to have a predictor
for the historical daily rates. See the \code{hotel_rates.R} file in the
\code{data-raw} directory of the package to understand other filters used when
creating this version of the data.

The \code{agent} and \code{company} fields were changed from random characters to use
a set of random names.

The outcome column is \code{avg_price_per_room}.
\subsection{License}{

No license was given for the data; See the reference below for source.
}
}
\examples{
\dontrun{
str(hotel_rates)
}
}
\references{
Antonio, N., de Almeida, A., and Nunes, L. (2019). Hotel booking demand
datasets. \emph{Data in Brief}, 22, 41-49.
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ad_data.R
\docType{data}
\name{ad_data}
\alias{ad_data}
\title{Alzheimer's disease data}
\source{
Kuhn, M., Johnson, K. (2013) \emph{Applied Predictive Modeling}, Springer.

Craig-Schapiro R, Kuhn M, Xiong C, Pickering EH, Liu J, Misko TP, et al.
(2011) Multiplexed Immunoassay Panel Identifies Novel CSF Biomarkers for
Alzheimer's Disease Diagnosis and Prognosis. PLoS ONE 6(4): e18850.
}
\value{
\item{ad_data}{a tibble}
}
\description{
Alzheimer's disease data
}
\details{
Craig-Schapiro et al. (2011) describe a clinical study of 333 patients,
including some with mild (but well-characterized) cognitive impairment as
well as healthy individuals. CSF samples were taken from all subjects. The
goal of the study was to determine if subjects in the early states of
impairment could be differentiated from cognitively healthy individuals.
Data collected on each subject included:
\itemize{
\item Demographic characteristics such as age and gender
\item Apolipoprotein E genotype
\item Protein measurements of Abeta, Tau, and a phosphorylated version of Tau (called pTau)
\item Protein measurements of 124 exploratory biomarkers, and
\item Clinical dementia scores
}

For these analyses, we have converted the scores to two classes: impaired
and healthy. The goal of this analysis is to create classification models
using the demographic and assay data to predict which patients have early
stages of disease.
}
\examples{
data(ad_data)
str(ad_data)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stackoverflow.R
\docType{data}
\name{stackoverflow}
\alias{stackoverflow}
\title{Annual Stack Overflow Developer Survey Data}
\source{
Julia Silge, \emph{Supervised Machine Learning Case Studies in R}

\verb{https://supervised-ml-course.netlify.com/chapter2}

Raw data: \verb{https://insights.stackoverflow.com/survey/}
}
\value{
\item{stackoverflow}{a tibble}
}
\description{
Annual Stack Overflow Developer Survey Data
}
\details{
These data are a collection of 5,594 data points collected on
developers. These data could be used to try to predict who works remotely
(as used in the source listed below).
}
\examples{
data(stackoverflow)
str(stackoverflow)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/permeability_qsar.R
\docType{data}
\name{permeability_qsar}
\alias{permeability_qsar}
\title{Predicting permeability from chemical information}
\source{
Kuhn, Max, and Kjell Johnson. \emph{Applied predictive modeling}. New York:
Springer, 2013.
}
\value{
\item{permeability_qsar}{a data frame}
}
\description{
A quantitative structure-activity relationship (QSAR) data set to predict
when a molecule can permeate cells.
}
\details{
This pharmaceutical data set was used to develop a model for predicting
compounds' permeability. In short, permeability is the measure of a
molecule's ability to cross a membrane. The body, for example, has notable
membranes between the body and brain, known as the blood-brain barrier, and
between the gut and body in the intestines. These membranes help the body
guard critical regions from receiving undesirable or detrimental substances.
For an orally taken drug to be effective in the brain, it first must pass
through the intestinal wall and then must pass through the blood-brain
barrier in order to be present for the desired neurological target.
Therefore, a compound's ability to permeate relevant biological membranes
is critically important to understand early in the drug discovery process.
Compounds that appear to be effective for a particular disease in research
screening experiments, but appear to be poorly permeable may need to be
altered in order improve permeability, and thus the compound's ability to
reach the desired target. Identifying permeability problems can help guide
chemists towards better molecules.

Permeability assays such as PAMPA and Caco-2 have been developed to help
measure compounds' permeability (Kansy et al, 1998). These screens are
effective at quantifying a compound's permeability, but the assay is
expensive labor intensive. Given a sufficient number of compounds that have
been screened, we could develop a predictive model for permeability in an
attempt to potentially reduce the need for the assay. In this project there
were 165 unique compounds; 1107 molecular fingerprints were determined for
each. A molecular fingerprint is a binary sequence of numbers that
represents the presence or absence of a specific molecular sub-structure.
The response is highly skewed, the predictors are sparse (15.5\% are present),
and many predictors are strongly associated.

Columns:
\itemize{
\item \code{permeability}: numeric
\item \code{chem_fp_0001} - \code{chem_fp_1107}: numeric
}
}
\examples{
data(permeability_qsar)
str(permeability_qsar)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/leaf_id_flavia.R
\docType{data}
\name{leaf_id_flavia}
\alias{leaf_id_flavia}
\title{Leaf identification data (Flavia)}
\source{
Lakshika, Jayani PG, and Thiyanga S. Talagala. "Computer-aided interpretable
features for leaf image classification." \emph{arXiv preprint} arXiv:2106.08077
(2021).

\url{https://github.com/SMART-Research/leaffeatures_paper}
}
\value{
\item{leaf_id_flavia}{a data frame}
}
\description{
Image analysis of leaves to predict species.
}
\details{
From the original manuscript: "The Flavia dataset contains 1907 leaf images.
There are 32 different species and each has 50-77 images. Scanners and
digital cameras are used to acquire the leaf images on a plain background.
The isolated leaf images contain blades only, without a petiole. These leaf
images are collected from the most common plants in Yangtze, Delta,
China. Those leaves were sampled on the campus of the Nanjing University and
the Sun Yat-Sen arboretum, Nanking, China."

The reference below has details information on the features used for
prediction.

Columns:
\itemize{
\item \code{species}:  factor (32 levels)
\item \code{apex}:  factor (9 levels)
\item \code{base}:  factor (6 levels)
\item \code{shape}:  factor (5 levels)
\item \code{denate_edge}:  factor (levels: 'no' and 'yes')
\item \code{lobed_edge}:  factor (levels: 'no' and 'yes')
\item \code{smooth_edge}:  factor (levels: 'no' and 'yes')
\item \code{toothed_edge}:  factor (levels: 'no' and 'yes')
\item \code{undulate_edge}:  factor (levels: 'no' and 'yes')
\item \code{outlying_polar}:  numeric
\item \code{skewed_polar}:  numeric
\item \code{clumpy_polar}:  numeric
\item \code{sparse_polar}:  numeric
\item \code{striated_polar}:  numeric
\item \code{convex_polar}:  numeric
\item \code{skinny_polar}:  numeric
\item \code{stringy_polar}:  numeric
\item \code{monotonic_polar}:  numeric
\item \code{outlying_contour}:  numeric
\item \code{skewed_contour}:  numeric
\item \code{clumpy_contour}:  numeric
\item \code{sparse_contour}:  numeric
\item \code{striated_contour}:  numeric
\item \code{convex_contour}:  numeric
\item \code{skinny_contour}:  numeric
\item \code{stringy_contour}:  numeric
\item \code{monotonic_contour}:  numeric
\item \code{num_max_points}:  numeric
\item \code{num_min_points}:  numeric
\item \code{diameter}:  numeric
\item \code{area}:  numeric
\item \code{perimeter}:  numeric
\item \code{physiological_length}:  numeric
\item \code{physiological_width}:  numeric
\item \code{aspect_ratio}:  numeric
\item \code{rectangularity}:  numeric
\item \code{circularity}:  numeric
\item \code{compactness}:  numeric
\item \code{narrow_factor}:  numeric
\item \code{perimeter_ratio_diameter}:  numeric
\item \code{perimeter_ratio_length}:  numeric
\item \code{perimeter_ratio_lw}:  numeric
\item \code{num_convex_points}:  numeric
\item \code{perimeter_convexity}:  numeric
\item \code{area_convexity}:  numeric
\item \code{area_ratio_convexity}:  numeric
\item \code{equivalent_diameter}:  numeric
\item \code{eccentricity}:  numeric
\item \code{contrast}:  numeric
\item \code{correlation_texture}:  numeric
\item \code{inverse_difference_moments}:  numeric
\item \code{entropy}:  numeric
\item \code{mean_red_val}:  numeric
\item \code{mean_green_val}:  numeric
\item \code{mean_blue_val}:  numeric
\item \code{std_red_val}:  numeric
\item \code{std_green_val}:  numeric
\item \code{std_blue_val}:  numeric
\item \code{correlation}:  numeric
}
}
\examples{
data(leaf_id_flavia)
str(leaf_id_flavia)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/churn.R
\docType{data}
\name{mlc_churn}
\alias{mlc_churn}
\title{Customer churn data}
\source{
Originally at \verb{http://www.sgi.com/tech/mlc/}
}
\value{
\item{mlc_churn}{a tibble}
}
\description{
A data set from the MLC++ machine learning software for modeling customer
churn. There are 19 predictors, mostly numeric: \code{state} (categorical),
\code{account_length} \code{area_code} \code{international_plan} (yes/no),
\code{voice_mail_plan} (yes/no), \code{number_vmail_messages}
\code{total_day_minutes} \code{total_day_calls} \code{total_day_charge}
\code{total_eve_minutes} \code{total_eve_calls} \code{total_eve_charge}
\code{total_night_minutes} \code{total_night_calls}
\code{total_night_charge} \code{total_intl_minutes}
\code{total_intl_calls} \code{total_intl_charge}, and
\code{number_customer_service_calls}.
}
\details{
The outcome is contained in a column called \code{churn} (also yes/no).
A note in one of the source files states that the data are "artificial based
on claims similar to real world".
}
\examples{
data(mlc_churn)
str(mlc_churn)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bivariate.R
\docType{data}
\name{bivariate}
\alias{bivariate}
\alias{bivariate_train}
\alias{bivariate_test}
\alias{bivariate_val}
\title{Example bivariate classification data}
\value{
\item{bivariate_train, bivariate_test, bivariate_val}{tibbles}
}
\description{
Example bivariate classification data
}
\details{
These data are a simplified version of the segmentation data contained
in \code{caret}. There are three columns: \code{A} and \code{B} are predictors and the column
\code{Class} is a factor with levels "One" and "Two". There are three data sets:
one for training (n = 1009), validation (n = 300), and testing (n = 710).
}
\examples{
data(bivariate)
str(bivariate_train)
str(bivariate_val)
str(bivariate_test)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fine_foods.R
\docType{data}
\name{small_fine_foods}
\alias{small_fine_foods}
\alias{training_data}
\alias{testing_data}
\title{Fine foods example data}
\source{
https://snap.stanford.edu/data/web-FineFoods.html
}
\value{
\item{training_data,testing_data}{tibbles}
}
\description{
Fine foods example data
}
\details{
These data are from Amazon, who describe it as "This dataset consists of
reviews of fine foods from amazon. The data span a period of more than 10
years, including all ~500,000 reviews up to October 2012. Reviews include
product and user information, ratings, and a plaintext review."

A subset of the data are contained here and are split into a training and
test set. The training set sampled 10 products and retained all of their
individual reviews. Since the reviews within these products are correlated,
we recommend resampling the data using a leave-one-product-out approach. The
test set sampled 500 products that were not included in the training set
and selected a single review at random for each.

There is a column for the product, a column for the text of the review, and
a factor column for a class variable. The outcome is whether the reviewer
gave the product a 5-star rating or not.
}
\examples{
data(small_fine_foods)
str(training_data)
str(testing_data)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/okc_text.R
\docType{data}
\name{okc_text}
\alias{okc_text}
\title{OkCupid text data}
\source{
Kim, A. Y., and A. Escobedo-Land. 2015. "OkCupid Data for
Introductory Statistics and Data Science Courses." \emph{Journal of
Statistics Education: An International Journal on the Teaching and
Learning of Statistics}.
}
\value{
\item{okc_text}{a tibble}
}
\description{
These are a sample of columns and users of OkCupid dating
website. The data are from Kim and Escobedo-Land (2015).
Permission to use this data set was explicitly granted by
OkCupid. The data set contains 10 text fields filled out by
users. There is an field called \code{Class} that is a factor with
levels "stem" and "other" where a value of "stem" means that
the user had a job in Science, Technology, Engineering, or
Math.
}
\examples{
data(okc_text)
str(okc_text)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/oils.R
\docType{data}
\name{oils}
\alias{oils}
\title{Fatty acid composition of commercial oils}
\source{
Brodnjak-Voncina et al. (2005). Multivariate data analysis in
classification of vegetable oils characterized by the content of fatty
acids, \emph{Chemometrics and Intelligent Laboratory Systems}, Vol.
75:31-45.
}
\value{
\item{oils}{a tibble}
}
\description{
Fatty acid concentrations of commercial oils were measured using gas
chromatography.  The data is used to predict the type of oil.  Note that
only the known oils are in the data set. Also, the authors state that there
are 95 samples of known oils. However, we count 96 in Table 1 (pgs.  33-35).
}
\examples{
data(oils)
str(oils)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/steroidogenic_toxicity.R
\docType{data}
\name{steroidogenic_toxicity}
\alias{steroidogenic_toxicity}
\title{Predicting steroidogenic toxicity with assay data}
\source{
Maglich, J. M., Kuhn, M., Chapin, R. E., & Pletcher, M. T. (2014). More than
just hormones: H295R cells as predictors of reproductive toxicity.
\emph{Reproductive Toxicology}, 45, 77-86.
}
\value{
A tibble with columns
\itemize{
\item \code{class}: factor(levels: toxic and nontoxic)
\item \code{cyp_11a1}: numeric
\item \code{cyp_11b1}: numeric
\item \code{cyp_11b2}: numeric
\item \code{cyp_17a1}: numeric
\item \code{cyp_19a1}: numeric
\item \code{cyp_21a1}: numeric
\item \code{hsd3b2}: numeric
\item \code{star}: numeric
\item \code{progesterone}: numeric
\item \code{testosterone}: numeric
\item \code{dhea}: numeric
\item \code{cortisol}: numeric
}
}
\description{
A set of \emph{in vitro} assays are used to quantify the risk of reproductive
toxicity via the disruption of steroidogenic pathways.
}
\details{
H295R cells were used to measure the effect with two sets of assay results.
The first includes a set of protein measurements on: cytochrome P450 enzymes
("cyp"s), STAR, and 3BHSD2. The second include hormone measurements for
DHEA, progesterone, testosterone, and cortisol.

Columns:
\itemize{
\item \code{class}: factor (levels: 'toxic' and 'nontoxic')
\item \code{cyp_11a1}: numeric
\item \code{cyp_11b1}: numeric
\item \code{cyp_11b2}: numeric
\item \code{cyp_17a1}: numeric
\item \code{cyp_19a1}: numeric
\item \code{cyp_21a1}: numeric
\item \code{hsd3b2}: numeric
\item \code{star}: numeric
\item \code{progesterone}: numeric
\item \code{testosterone}: numeric
\item \code{dhea}: numeric
\item \code{cortisol}: numeric
}
}
\examples{
data(steroidogenic_toxicity)
str(steroidogenic_toxicity)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_times.R
\docType{data}
\name{check_times}
\alias{check_times}
\title{Execution time data}
\source{
CRAN
}
\value{
\item{check_times}{a data frame}
}
\description{
These data were collected from the CRAN web page for 13,626 R
packages. The time to complete the standard package checking
routine was collected In some cases, the package checking
process is stopped due to errors and these data are treated as
censored. It is less than 1 percent.
}
\details{
As predictors, the associated package source code were
downloaded and parsed to create predictors, including
\itemize{
\item \code{authors}: The number of authors in the author field.
\item \code{imports}: The number of imported packages.
\item \code{suggests}: The number of packages suggested.
\item \code{depends}: The number of hard dependencies.
\item \code{Roxygen}: a binary indicator for whether Roxygen was used
for documentation.
\item \code{gh}: a binary indicator for whether the URL field contained
a GitHub link.
\item \code{rforge}: a binary indicator for whether the URL field
contained a link to R-forge.
\item \code{descr}: The number of characters (or, in some cases, bytes)
in the description field.
\item \code{r_count}: The number of R files in the R directory.
\item \code{r_size}: The total disk size of the R files.
\item \code{ns_import}: Estimated number of imported functions or methods.
\item \code{ns_export}: Estimated number of exported functions or methods.
\item \code{s3_methods}: Estimated number of S3 methods.
\item \code{s4_methods}: Estimated number of S4 methods.
\item \code{doc_count}: How many Rmd or Rnw files in the vignettes
directory.
\item \code{doc_size}: The disk size of the Rmd or Rnw files.
\item \code{src_count}: The number of files in the \code{src} directory.
\item \code{src_size}: The size on disk of files in the \code{src} directory.
\item \code{data_count}  The number of files in the \code{data} directory.
\item \code{data_size}: The size on disk of files in the \code{data} directory.
\item \code{testthat_count}: The number of files in the \code{testthat}
directory.
\item \code{testthat_size}: The size on disk of files in the \code{testthat}
directory.
\item \code{check_time}: The time (in seconds) to run \verb{R CMD check}
using the "r-devel-windows-ix86+x86_64` flavor.
\item \code{status}: An indicator for whether the tests completed.
}

Data were collected on 2019-01-20.
}
\examples{
data(check_times)
str(check_times)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/concrete.R
\docType{data}
\name{concrete}
\alias{concrete}
\title{Compressive strength of concrete mixtures}
\source{
Yeh I (2006). "Analysis of Strength of Concrete Using Design of Experiments
and Neural Networks." \emph{Journal of Materials in Civil Engineering}, 18, 597-604.

Kuhn, M., Johnson, K. (2013) \emph{Applied Predictive Modeling}, Springer.
}
\value{
\item{concrete}{a tibble}
}
\description{
Yeh (2006) describes an aggregated data set for experimental designs used to
test the compressive strength of concrete mixtures. The data are used by
Kuhn and Johnson (2013).
}
\examples{
data(concrete)
str(concrete)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/parabolic.R
\docType{data}
\name{parabolic}
\alias{parabolic}
\title{Parabolic class boundary data}
\value{
\item{parabolic}{a data frame}
}
\description{
Parabolic class boundary data
}
\details{
These data were simulated. There are two correlated predictors and
two classes in the factor outcome.
}
\examples{
data(parabolic)
str(parabolic)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/meats.R
\docType{data}
\name{meats}
\alias{meats}
\title{Fat, water and protein content of meat samples}
\value{
\item{meats}{a tibble}
}
\description{
"These data are recorded on a Tecator Infratec Food and Feed Analyzer
working in the wavelength range 850 - 1050 nm by the Near Infrared
Transmission (NIT) principle. Each sample contains finely chopped pure meat
with different moisture, fat and protein contents.
}
\details{
If results from these data are used in a publication we want you to mention
the instrument and company name (Tecator) in the publication.  In addition,
please send a preprint of your article to:

Karin Thente, Tecator AB, Box 70, S-263 21 Hoganas, Sweden

The data are available in the public domain with no responsibility from the
original data source. The data can be redistributed as long as this
permission note is attached."

"For each meat sample the data consists of a 100 channel spectrum of
absorbances and the contents of moisture (water), fat and protein.  The
absorbance is -log10 of the transmittance measured by the spectrometer. The
three contents, measured in percent, are determined by analytic chemistry."

Included here are the training, monitoring and test sets.
}
\examples{

data(meats)
str(meats)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/two_class_dat.R
\docType{data}
\name{two_class_dat}
\alias{two_class_dat}
\title{Two class data}
\value{
\item{two_class_dat}{a data frame}
}
\description{
Two class data
}
\details{
There are artificial data with two predictors (\code{A} and \code{B}) and
a factor outcome variable (\code{Class}).
}
\examples{
data(two_class_dat)
str(two_class_dat)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulations.R
\name{sim_classification}
\alias{sim_classification}
\alias{sim_regression}
\alias{sim_noise}
\alias{sim_logistic}
\alias{sim_multinomial}
\title{Simulate datasets}
\usage{
sim_classification(
  num_samples = 100,
  method = "caret",
  intercept = -5,
  num_linear = 10,
  keep_truth = FALSE
)

sim_regression(
  num_samples = 100,
  method = "sapp_2014_1",
  std_dev = NULL,
  factors = FALSE,
  keep_truth = FALSE
)

sim_noise(
  num_samples,
  num_vars,
  cov_type = "exchangeable",
  outcome = "none",
  num_classes = 2,
  cov_param = 0
)

sim_logistic(num_samples, eqn, correlation = 0, keep_truth = FALSE)

sim_multinomial(
  num_samples,
  eqn_1,
  eqn_2,
  eqn_3,
  correlation = 0,
  keep_truth = FALSE
)
}
\arguments{
\item{num_samples}{Number of data points to simulate.}

\item{method}{A character string for the simulation method. For
classification, the single current option is "caret". For regression,
values can be \code{"sapp_2014_1"}, \code{"sapp_2014_2"}, \code{"van_der_laan_2007_1"},
\code{"van_der_laan_2007_2"}, \code{"hooker_2004"}, or \code{"worley_1987"}. See Details
below.}

\item{intercept}{The intercept for the linear predictor.}

\item{num_linear}{Number of diminishing linear effects.}

\item{keep_truth}{A logical: should the true outcome value be retained for
the data? If so, the column name is \code{.truth}.}

\item{std_dev}{Gaussian distribution standard deviation for residuals.
Default values are shown below in Details.}

\item{factors}{A single logical for whether the binary indicators should be
encoded as factors or not.}

\item{num_vars}{Number of noise predictors to create.}

\item{cov_type}{The multivariate normal correlation structure of the
predictors. Possible values are "exchangeable" and "toeplitz".}

\item{outcome}{A single character string for what type of independent outcome
should be simulated (if any). The default value of "none" produces no extra
columns. Using "classification" will generate a \code{class} column with
\code{num_classes} values, equally distributed. A value of "regression" results
in an \code{outcome} column that contains independent standard normal values.}

\item{num_classes}{When \code{outcome = "classification"}, the number of classes
to simulate.}

\item{cov_param}{A single numeric value for the exchangeable correlation
value or the base of the Toeplitz structure. See Details below.}

\item{eqn, eqn_1, eqn_2, eqn_3}{An R expression or  (one sided) formula that
only involves variables \code{A} and \code{B} that is used to compute the linear
predictor. External objects should not be used as symbols; see the examples
below on how to use external objects in the equations.}

\item{correlation}{A single numeric value for the correlation between variables
\code{A} and \code{B}.}
}
\description{
These functions can be used to generate simulated data for supervised
(classification and regression) and unsupervised modeling applications.
}
\details{
\subsection{Specific Regression and Classification methods}{

These functions provide several supervised simulation methods (and one
unsupervised). Learn more by \code{method}:
\subsection{\code{method = "caret"}}{

This is a simulated classification problem with two classes, originally
implemented in \code{\link[caret:twoClassSim]{caret::twoClassSim()}} with all numeric predictors. The
predictors are simulated in different sets. First, two multivariate normal
predictors (denoted here as \code{two_factor_1} and \code{two_factor_2}) are created
with a correlation of about 0.65. They change the log-odds using main
effects and an interaction:

\preformatted{  intercept - 4 * two_factor_1 + 4 * two_factor_2 + 2 * two_factor_1 * two_factor_2 }

The intercept is a parameter for the simulation and can be used to control
the amount of class imbalance.

The effects in the second set are linear with coefficients that alternate signs
and have a sequence of values between 2.5 and 0.25. For example, if there
were four predictors in this set, their contribution to the log-odds would
be

\preformatted{  -2.5 * linear_1 + 1.75 * linear_2 -1.00 * linear_3 + 0.25 * linear_4}

(Note that these column names may change based on the value of \code{num_linear}).

The third set is a nonlinear function of a single predictor ranging between
\verb{[0, 1]} called \code{non_linear_1} here:

\preformatted{  (non_linear_1^3) + 2 * exp(-6 * (non_linear_1 - 0.3)^2) }

The fourth set of informative predictors is copied from one of Friedman's
systems and use two more predictors (\code{non_linear_2} and \code{non_linear_3}):

\preformatted{  2 * sin(non_linear_2 * non_linear_3) }

All of these effects are added up to model the log-odds.
}

\subsection{\code{method = "sapp_2014_1"}}{

This regression simulation is from Sapp et al. (2014). There are 20
independent Gaussian random predictors with mean zero and a variance of 9.
The prediction equation is:

\preformatted{
  predictor_01 + sin(predictor_02) + log(abs(predictor_03)) +
   predictor_04^2 + predictor_05 * predictor_06 +
   ifelse(predictor_07 * predictor_08 * predictor_09 < 0, 1, 0) +
   ifelse(predictor_10 > 0, 1, 0) + predictor_11 * ifelse(predictor_11 > 0, 1, 0) +
   sqrt(abs(predictor_12)) + cos(predictor_13) + 2 * predictor_14 + abs(predictor_15) +
   ifelse(predictor_16 < -1, 1, 0) + predictor_17 * ifelse(predictor_17 < -1, 1, 0) -
   2 * predictor_18 - predictor_19 * predictor_20
}

The error is Gaussian with mean zero and variance 9.
}

\subsection{\code{method = "sapp_2014_2"}}{

This regression simulation is also from Sapp et al. (2014). There are 200
independent Gaussian predictors with mean zero and variance 16. The
prediction equation has an intercept of one and identical linear effects of
\code{log(abs(predictor))}.

The error is Gaussian with mean zero and variance 25.
}

\subsection{\code{method = "van_der_laan_2007_1"}}{

This is a regression simulation from van der Laan et al. (2007) with ten
random Bernoulli variables that have a 40\% probability of being a value of
one. The true regression equation is:

\preformatted{
  2 * predictor_01 * predictor_10 + 4 * predictor_02 * predictor_07 +
    3 * predictor_04 * predictor_05 - 5 * predictor_06 * predictor_10 +
    3 * predictor_08 * predictor_09 + predictor_01 * predictor_02 * predictor_04 -
    2 * predictor_07 * (1 - predictor_06) * predictor_02 * predictor_09 -
    4 * (1 - predictor_10) * predictor_01 * (1 - predictor_04)
}

The error term is standard normal.
}

\subsection{\code{method = "van_der_laan_2007_2"}}{

This is another regression simulation from van der Laan et al. (2007)  with
twenty Gaussians with mean zero and variance 16. The prediction equation is:

\preformatted{
  predictor_01 * predictor_02 + predictor_10^2 - predictor_03 * predictor_17 -
    predictor_15 * predictor_04 + predictor_09 * predictor_05 + predictor_19 -
    predictor_20^2 + predictor_09 * predictor_08
}

The error term is also Gaussian with mean zero and variance 16.
}

\subsection{\code{method = "hooker_2004"}}{

Hooker (2004) and Sorokina \emph{at al} (2008) used the following:

\preformatted{
    pi ^ (predictor_01 * predictor_02) * sqrt( 2 * predictor_03 ) -
    asin(predictor_04) + log(predictor_03  + predictor_05) -
   (predictor_09 / predictor_10) * sqrt (predictor_07 / predictor_08) -
    predictor_02 * predictor_07
}

Predictors 1, 2, 3, 6, 7, and 9 are standard uniform while the others are
uniform on \verb{[0.6, 1.0]}. The errors are normal with mean zero and default
standard deviation of 0.25.
}

\subsection{\code{method = "worley_1987"}}{

The simulation system from Worley (1987) is based on a mechanistic model for
the flow rate of liquids from two aquifers positioned vertically (i.e.,
the "upper" and "lower" aquifers). There are two sets of predictors:
\itemize{
\item the borehole radius (\code{radius_borehole} from 0.05 to 0.15) and length
(\code{length_borehole} from 1,120 to 1,680) .
\item The radius of effect that the system has on collecting water
(\code{radius_influence} from 100 to 50,000)
}

and physical properties:
\itemize{
\item \code{transmissibility_upper_aq}
\item \code{potentiometric_upper_aq}
\item \code{transmissibility_lower_aq}
\item \code{potentiometric_lower_aq}
\item \code{conductivity_borehole}
}

A multiplicative error structure is used; the mechanistic equation is
multiplied by an exponentiated Gaussian random error.

The references give feasible ranges for each of these variables. See also
Morris \emph{et al} (1993).
}

}

\subsection{\code{sim_noise()}}{

This function simulates a number of random normal variables with mean zero.
The values can be independent if \code{cov_param = 0}. Otherwise the values are
multivariate normal with non-diagonal covariance matrices. For
\code{cov_type = "exchangeable"}, the structure has unit variances and covariances
of \code{cov_param}. With \code{cov_type = "toeplitz"}, the covariances have an
exponential pattern (see example below).
}

\subsection{Logistic simulation}{

\code{sim_logistic()} provides a flexible interface to simulating a logistic
regression model with two multivariate normal variables \code{A} and \code{B} (with
zero mean, unit variances and correlation determined by the \code{correlation}
argument).

For example, using \code{eqn = A + B} would specify that the true probability of
the event was

\preformatted{
   prob = 1 / (1 + exp(A + B))
}

The class levels for the outcome column are \code{"one"} and \code{"two"}.
}

\subsection{Multinomial simulation}{

\code{sim_multinomial()} can generate data with classes \code{"one"}, \code{"two"}, and
\code{"three"} based on the values in arguments \code{eqn_1}, \code{eqn_2}, and \code{eqn_3},
respectfully. Like \code{\link[=sim_logistic]{sim_logistic()}} these equations use predictors \code{A} and
\code{B}.

The individual equations are evaluated and exponentiated. After this, their
values are, for each row of data, normalized to add up to one. These
probabilities are them passed to \code{\link[stats:Multinom]{stats::rmultinom()}} to generate the outcome
values.
}
}
\examples{
set.seed(1)
sim_regression(100)
sim_classification(100)

# Flexible logistic regression simulation
if (rlang::is_installed("ggplot2")) {
  library(dplyr)
  library(ggplot2)

  sim_logistic(1000, ~ .1 + 2 * A - 3 * B + 1 * A *B, corr = .7) |>
    ggplot(aes(A, B, col = class)) +
    geom_point(alpha = 1/2) +
    coord_equal()

  f_xor <- ~ 10 * xor(A > 0, B < 0)
  # or
  f_xor <- rlang::expr(10 * xor(A > 0, B < 0))

  sim_logistic(1000, f_xor, keep_truth = TRUE) |>
    ggplot(aes(A, B, col = class)) +
    geom_point(alpha = 1/2) +
    coord_equal() +
    theme_bw()
}

## How to use external symbols:

a_coef <- 2
# splice the value in using rlang's !! operator
lp_eqn <- rlang::expr(!!a_coef * A+B)
lp_eqn
sim_logistic(5, lp_eqn)

# Flexible multinomial regression simulation
if (rlang::is_installed("ggplot2")) {

}
}
\references{
Hooker, G. (2004, August). Discovering additive structure in black box
functions. In \emph{Proceedings of the tenth ACM SIGKDD international conference
on Knowledge discovery and data mining} (pp. 575-580).
DOI: 10.1145/1014052.1014122

Morris, M. D., Mitchell, T. J., and Ylvisaker, D. (1993). Bayesian design
and analysis of computer experiments: use of derivatives in surface
prediction. \emph{Technometrics}, 35(3), 243-255.

Sapp, S., van der Laan, M. J., and Canny, J. (2014). Subsemble: an ensemble
method for combining subset-specific algorithm fits. \emph{Journal of applied
statistics}, 41(6), 1247-1259. DOI: 10.1080/02664763.2013.864263

Sorokina, D., Caruana, R., Riedewald, M., and Fink, D. (2008, July). Detecting
statistical interactions with additive groves of trees. In \emph{Proceedings of
the 25th international conference on Machine learning} (pp. 1000-1007).
DOI: 10.1145/1390156.1390282

Van der Laan, M. J., Polley, E. C., and Hubbard, A. E. (2007). Super learner.
\emph{Statistical applications in genetics and molecular biology}, 6(1).
DOI: 10.2202/1544-6115.1309.

Worley, B. A. (1987). Deterministic uncertainty analysis (No. ORNL-6428). Oak
Ridge National Lab.(ORNL), Oak Ridge, TN/
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Chicago.R
\docType{data}
\name{Chicago}
\alias{Chicago}
\alias{stations}
\title{Chicago ridership data}
\source{
Kuhn and Johnson (2020), \emph{Feature Engineering and Selection},
Chapman and Hall/CRC . \url{https://bookdown.org/max/FES/} and
\url{https://github.com/topepo/FES}
}
\value{
\item{Chicago}{a tibble} \item{stations}{a vector of station names}
}
\description{
Chicago ridership data
}
\details{
These data are from Kuhn and Johnson (2020) and contain an
\emph{abbreviated} training set for modeling the number of people (in thousands)
who enter the Clark and Lake L station.

The \code{date} column corresponds to the current date. The columns with station
names (\code{Austin} through \code{California}) are a \emph{sample} of the columns used in
the original analysis (for file size reasons). These are 14 day lag
variables (i.e. \verb{date - 14 days}). There are columns related to weather and
sports team schedules.

The station at 35th and Archer is contained in the column \code{Archer_35th} to
make it a valid R column name.
}
\examples{
data(Chicago)
str(Chicago)
stations
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/biomass.R
\docType{data}
\name{biomass}
\alias{biomass}
\title{Biomass data}
\source{
Ghugare, S. B., Tiwary, S., Elangovan, V., and Tambe, S. S. (2013).
Prediction of Higher Heating Value of Solid Biomass Fuels Using Artificial
Intelligence Formalisms. \emph{BioEnergy Research}, 1-12.
}
\value{
\item{biomass}{a data frame}
}
\description{
Ghugare et al (2014) contains a data set where different biomass fuels are
characterized by the amount of certain molecules (carbon, hydrogen, oxygen,
nitrogen, and sulfur) and the corresponding higher heating value (HHV).
These data are from their Table S.2 of the Supplementary Materials
}
\examples{
data(biomass)
str(biomass)
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/car_prices.R
\docType{data}
\name{car_prices}
\alias{car_prices}
\title{Kelly Blue Book resale data for 2005 model year GM cars}
\source{
Kuiper, S. (2008). Introduction to Multiple Regression: How Much Is Your Car Worth?,
\emph{Journal of Statistics Education}, Vol. 16
\url{https://jse.amstat.org/jse_archive.htm#2008}.
}
\value{
\item{car_prices}{data frame of the suggested retail price (column \code{Price}) and various
characteristics of each car (columns \code{Mileage}, \code{Cylinder}, \code{Doors}, \code{Cruise},
\code{Sound}, \code{Leather}, \code{Buick}, \code{Cadillac}, \code{Chevy}, \code{Pontiac}, \code{Saab},
\code{Saturn}, \code{convertible}, \code{coupe}, \code{hatchback}, \code{sedan} and \code{wagon})}
}
\description{
Kuiper (2008) collected data on Kelly Blue Book resale data for 804 GM cars (2005 model year).
}
\examples{
data(car_prices)
str(car_prices)
}
\keyword{datasets}
